# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Texas."""


ABBOTT_CITY = "00100"
ABERNATHY_CITY = "00160"
ABILENE_CITY = "01000"
ABRAM_CDP = "01060"
ACALA_CDP = "01084"
ACKERLY_CITY = "01108"
ADDISON_TOWN = "01240"
ADRIAN_CITY = "01324"
AGUA_DULCE_CDP = "01390"
AGUA_DULCE_CITY = "01396"
AGUILARES_CDP = "01420"
AIRPORT_HEIGHTS_CDP = "01500"
AIRPORT_ROAD_ADDITION_CDP = "01514"
ALAMO_BEACH_CDP = "01594"
ALAMO_HEIGHTS_CITY = "01600"
ALAMO_CITY = "01576"
ALANREED_CDP = "01612"
ALBA_TOWN = "01636"
ALBANY_CITY = "01648"
ALDINE_CDP = "01696"
ALEDO_CITY = "01744"
ALFRED_CDP = "01816"
ALICE_ACRES_CDP = "01858"
ALICE_CITY = "01852"
ALLEN_CITY = "01924"
ALLISON_CDP = "02032"
ALMA_TOWN = "02044"
ALPINE_CITY = "02104"
ALTO_BONITO_HEIGHTS_CDP = "02194"
ALTO_TOWN = "02188"
ALTON_CITY = "02212"
ALVARADO_CITY = "02260"
ALVIN_CITY = "02272"
ALVORD_TOWN = "02284"
AMADA_ACRES_CDP = "02286"
AMARGOSA_CDP = "02290"
AMARILLO_CITY = "03000"
AMAYA_CDP = "03008"
AMES_CITY = "03072"
AMHERST_CITY = "03084"
AMISTAD_CDP = "03096"
ANACUA_CDP = "03126"
ANAHUAC_CITY = "03144"
ANDERSON_CITY = "03192"
ANDREWS_CITY = "03216"
ANGLETON_CITY = "03264"
ANGUS_CITY = "03288"
ANNA_CITY = "03300"
ANNETTA_NORTH_TOWN = "03340"
ANNETTA_SOUTH_TOWN = "03342"
ANNETTA_TOWN = "03336"
ANNONA_TOWN = "03360"
ANSON_CITY = "03372"
ANTHONY_TOWN = "03432"
ANTON_CITY = "03540"
APPLEBY_CITY = "03564"
AQUILLA_CITY = "03588"
ARANSAS_PASS_CITY = "03600"
ARCHER_CITY_CITY = "03696"
ARCOLA_CITY = "03708"
ARGYLE_CITY = "03768"
ARLINGTON_CITY = "04000"
ARP_CITY = "04156"
ARROYO_COLORADO_ESTATES_CDP = "04174"
ARROYO_GARDENS_CDP = "04176"
ASHERTON_CITY = "04300"
ASPERMONT_TOWN = "04408"
ATASCOCITA_CDP = "04462"
ATHENS_CITY = "04504"
ATLANTA_CITY = "04516"
AUBREY_CITY = "04600"
AURORA_CITY = "04672"
AUSTIN_CITY = "05000"
AUSTWELL_CITY = "05036"
AVERY_TOWN = "05072"
AVINGER_TOWN = "05084"
AZLE_CITY = "05168"
B_AND_E_CDP = "05520"
BACLIFF_CDP = "05180"
BAILEY_CITY = "05264"
BAILEYS_PRAIRIE_VILLAGE = "05288"
BAIRD_CITY = "05336"
BALCH_SPRINGS_CITY = "05372"
BALCONES_HEIGHTS_CITY = "05384"
BALLINGER_CITY = "05456"
BALMORHEA_CITY = "05468"
BANDERA_CITY = "05528"
BANGS_CITY = "05552"
BANQUETE_CDP = "05576"
BARDWELL_CITY = "05612"
BARKSDALE_CDP = "05648"
BARRERA_CDP = "05690"
BARRETT_CDP = "05696"
BARRY_CITY = "05708"
BARSTOW_CITY = "05720"
BARTLETT_CITY = "05732"
BARTON_CREEK_CDP = "05750"
BARTONVILLE_TOWN = "05768"
BASTROP_CITY = "05864"
BATESVILLE_CDP = "05924"
BAY_CITY_CITY = "05984"
BAYOU_VISTA_CITY = "06060"
BAYSIDE_TOWN = "06104"
BAYTOWN_CITY = "06128"
BAYVIEW_TOWN = "06140"
BEACH_CITY_CITY = "06200"
BEAR_CREEK_RANCH_CDP = "06244"
BEAR_CREEK_VILLAGE = "06242"
BEASLEY_CITY = "06272"
BEAUMONT_CITY = "07000"
BEAUXART_GARDENS_CDP = "07036"
BEAVER_CREEK_CDP = "07042"
BECKVILLE_CITY = "07108"
BEDFORD_CITY = "07132"
BEDIAS_CITY = "07144"
BEE_CAVE_CITY = "07156"
BEEVILLE_CITY = "07192"
BELLAIRE_CITY = "07300"
BELLEVUE_CITY = "07396"
BELLMEAD_CITY = "07408"
BELLS_TOWN = "07420"
BELLVILLE_CITY = "07432"
BELTERRA_CDP = "07486"
BELTON_CITY = "07492"
BEN_ARNOLD_CDP = "07516"
BEN_BOLT_CDP = "07540"
BEN_WHEELER_CDP = "07708"
BENAVIDES_CITY = "07528"
BENBROOK_CITY = "07552"
BENJAMIN_PEREZ_CDP = "07642"
BENJAMIN_CITY = "07636"
BERRYVILLE_TOWN = "07852"
BERTRAM_CITY = "07864"
BEVERLY_HILLS_CITY = "08104"
BEVIL_OAKS_CITY = "08128"
BIG_LAKE_CITY = "08212"
BIG_SANDY_TOWN = "08224"
BIG_SPRING_CITY = "08236"
BIG_THICKET_LAKE_ESTATES_CDP = "08240"
BIG_WELLS_CITY = "08260"
BIGFOOT_CDP = "08164"
BISHOP_HILLS_TOWN = "08398"
BISHOP_CITY = "08392"
BIVINS_CDP = "08404"
BIXBY_CDP = "08410"
BLACKWELL_CITY = "08488"
BLANCO_CITY = "08536"
BLANKET_TOWN = "08596"
BLEDSOE_CDP = "08644"
BLESSING_CDP = "08668"
BLOOMBURG_TOWN = "08752"
BLOOMING_GROVE_TOWN = "08788"
BLOOMINGTON_CDP = "08800"
BLOSSOM_CITY = "08812"
BLUE_BERRY_HILL_CDP = "08830"
BLUE_MOUND_CITY = "08860"
BLUE_RIDGE_CITY = "08872"
BLUETOWN_CDP = "08908"
BLUFF_DALE_CDP = "08932"
BLUM_TOWN = "09004"
BOERNE_CITY = "09160"
BOGATA_CITY = "09172"
BOLING_CDP = "09232"
BOLIVAR_PENINSULA_CDP = "09250"
BONANZA_HILLS_CDP = "09310"
BONHAM_CITY = "09328"
BONNEY_VILLAGE = "09388"
BOOKER_TOWN = "09448"
BORGER_CITY = "09556"
BOTINES_CDP = "09598"
BOVINA_CITY = "09628"
BOWIE_CITY = "09640"
BOX_CANYON_CDP = "09656"
BOYD_TOWN = "09748"
BOYS_RANCH_CDP = "09796"
BRACKETTVILLE_CITY = "09868"
BRADY_CITY = "09916"
BRAZORIA_CITY = "10072"
BRAZOS_CDP = "10084"
BRAZOS_COUNTRY_CITY = "10090"
BRECKENRIDGE_CITY = "10132"
BREMOND_CITY = "10144"
BRENHAM_CITY = "10156"
BRIAR_CDP = "10192"
BRIARCLIFF_VILLAGE = "10197"
BRIAROAKS_CITY = "10216"
BRIDGE_CITY_CITY = "10252"
BRIDGEPORT_CITY = "10264"
BRIGGS_CDP = "10276"
BRISTOL_CDP = "10336"
BROADDUS_TOWN = "10384"
BRONTE_TOWN = "10528"
BROOKSHIRE_CITY = "10636"
BROOKSIDE_VILLAGE_CITY = "10648"
BROOKSTON_CDP = "10660"
BROWNDELL_CITY = "10708"
BROWNFIELD_CITY = "10720"
BROWNSBORO_CITY = "10756"
BROWNSVILLE_CITY = "10768"
BROWNWOOD_CITY = "10780"
BRUCEVILLE_EDDY_CITY = "10828"
BRUNDAGE_CDP = "10852"
BRUNI_CDP = "10876"
BRUSHY_CREEK_CDP = "10897"
BRYAN_CITY = "10912"
BRYSON_CITY = "10960"
BUCHANAN_DAM_CDP = "10984"
BUCHANAN_LAKE_VILLAGE_CDP = "10990"
BUCKHOLTS_TOWN = "11020"
BUDA_CITY = "11080"
BUENA_VISTA_CDP = "11102"
BUFFALO_GAP_TOWN = "11128"
BUFFALO_SPRINGS_VILLAGE = "11155"
BUFFALO_CITY = "11116"
BULLARD_TOWN = "11212"
BULVERDE_CITY = "11224"
BUNA_CDP = "11236"
BUNKER_HILL_VILLAGE_CITY = "11300"
BURKBURNETT_CITY = "11368"
BURKE_CITY = "11380"
BURLESON_CITY = "11428"
BURLINGTON_CDP = "11440"
BURNET_CITY = "11464"
BURTON_CITY = "11536"
BUSHLAND_CDP = "11572"
BUTTERFIELD_CDP = "11626"
BYERS_CITY = "11644"
BYNUM_TOWN = "11656"
CACTUS_CITY = "11692"
CADDO_MILLS_CITY = "11716"
CADE_LAKES_CDP = "11725"
CALDWELL_CITY = "11836"
CALLENDER_LAKE_CDP = "11940"
CALLISBURG_CITY = "11968"
CALVERT_CITY = "11992"
CAMARGITO_CDP = "12010"
CAMERON_PARK_CDP = "12045"
CAMERON_CITY = "12040"
CAMP_SWIFT_CDP = "12334"
CAMP_WOOD_CITY = "12388"
CAMPBELL_CITY = "12112"
CAMPO_VERDE_CDP = "12226"
CANADIAN_CITY = "12412"
CANEY_CITY_TOWN = "12472"
CANTON_CITY = "12496"
CANTU_ADDITION_CDP = "12502"
CANUTILLO_CDP = "12508"
CANYON_CREEK_CDP = "12562"
CANYON_LAKE_CDP = "12580"
CANYON_CITY = "12532"
CAPE_ROYALE_CDP = "12600"
CARBON_TOWN = "12736"
CARLS_CORNER_TOWN = "12895"
CARLSBAD_CDP = "12892"
CARLTON_CDP = "12904"
CARMINE_CITY = "12916"
CARRIZO_HILL_CDP = "12982"
CARRIZO_SPRINGS_CITY = "12988"
CARROLLTON_CITY = "13024"
CARTER_CDP = "13075"
CARTHAGE_CITY = "13108"
CASA_BLANCA_CDP = "13128"
CASAS_CDP = "13150"
CASHION_COMMUNITY_CITY = "13198"
CASTLE_HILLS_CITY = "13276"
CASTROVILLE_CITY = "13312"
CATARINA_CDP = "13324"
CEDAR_CREEK_CDP = "13432"
CEDAR_HILL_CITY = "13492"
CEDAR_PARK_CITY = "13552"
CEDAR_POINT_CDP = "13570"
CELESTE_CITY = "13672"
CELINA_CITY = "13684"
CENTER_POINT_CDP = "13828"
CENTER_CITY = "13732"
CENTERVILLE_CITY = "13900"
CENTRAL_GARDENS_CDP = "13972"
CHANDLER_CITY = "14224"
CHANNELVIEW_CDP = "14236"
CHANNING_CITY = "14260"
CHAPARRITO_CDP = "14266"
CHAPENO_CDP = "14290"
CHARLOTTE_CITY = "14404"
CHESTER_TOWN = "14584"
CHICO_CITY = "14620"
CHILDRESS_CITY = "14668"
CHILLICOTHE_CITY = "14680"
CHILTON_CDP = "14692"
CHINA_GROVE_TOWN = "14716"
CHINA_SPRING_CDP = "14740"
CHINA_CITY = "14704"
CHIRENO_CITY = "14776"
CHRISTINE_TOWN = "14860"
CHRISTOVAL_CDP = "14872"
CHULA_VISTA_CDP_CAMERON_COUNTY = "14880"
CHULA_VISTA_CDP_MAVERICK_COUNTY = "14881"
CHULA_VISTA_CDP_ZAVALA_COUNTY = "14882"
CIBOLO_CITY = "14920"
CIENEGAS_TERRACE_CDP = "14927"
CINCO_RANCH_CDP = "14929"
CIRCLE_D_KC_ESTATES_CDP = "14986"
CISCO_CITY = "15004"
CITRUS_CITY_CDP = "15028"
CLARENDON_CITY = "15112"
CLARKSVILLE_CITY_CITY = "15172"
CLARKSVILLE_CITY = "15160"
CLAUDE_CITY = "15196"
CLAY_CDP = "15232"
CLEAR_LAKE_SHORES_CITY = "15328"
CLEBURNE_CITY = "15364"
CLEVELAND_CITY = "15436"
CLIFTON_CITY = "15472"
CLINT_TOWN = "15544"
CLOVERLEAF_CDP = "15628"
CLUTE_CITY = "15652"
CLYDE_CITY = "15676"
COAHOMA_TOWN = "15700"
COCKRELL_HILL_CITY = "15796"
COFFEE_CITY_TOWN = "15820"
COLDSPRING_CITY = "15892"
COLEMAN_CITY = "15916"
COLLEGE_STATION_CITY = "15976"
COLLEYVILLE_CITY = "15988"
COLLINSVILLE_TOWN = "16036"
COLMESNEIL_CITY = "16048"
COLORADO_ACRES_CDP = "16110"
COLORADO_CITY_CITY = "16120"
COLUMBUS_CITY = "16168"
COMANCHE_CITY = "16192"
COMBES_TOWN = "16204"
COMBINE_CITY = "16216"
COMFORT_CDP = "16228"
COMMERCE_CITY = "16240"
COMO_TOWN = "16252"
CONCEPCION_CDP = "16300"
CONROE_CITY = "16432"
CONVERSE_CITY = "16468"
COOL_CITY = "16540"
COOLIDGE_TOWN = "16552"
COOPER_CITY = "16564"
COPPELL_CITY = "16612"
COPPER_CANYON_TOWN = "16636"
COPPERAS_COVE_CITY = "16624"
CORINTH_CITY = "16696"
CORPUS_CHRISTI_CITY = "17000"
CORRIGAN_TOWN = "17036"
CORSICANA_CITY = "17060"
COTTONWOOD_SHORES_CITY = "17208"
COTTONWOOD_CITY = "17200"
COTULLA_CITY = "17216"
COUPLAND_CITY = "17312"
COVE_CITY = "17336"
COVINGTON_CITY = "17372"
COYANOSA_CDP = "17408"
COYOTE_ACRES_CDP = "17426"
COYOTE_FLATS_CITY = "17429"
CRANDALL_CITY = "17504"
CRANE_CITY = "17516"
CRANFILLS_GAP_CITY = "17540"
CRAWFORD_TOWN = "17564"
CREEDMOOR_CITY = "17612"
CRESSON_CITY = "17648"
CROCKETT_CITY = "17744"
CROSBY_CDP = "17756"
CROSBYTON_CITY = "17768"
CROSS_MOUNTAIN_CDP = "17811"
CROSS_PLAINS_TOWN = "17816"
CROSS_ROADS_TOWN = "17852"
CROSS_TIMBER_TOWN = "17917"
CROWELL_CITY = "17948"
CROWLEY_CITY = "17960"
CRYSTAL_CITY_CITY = "18020"
CUERO_CITY = "18092"
CUEVITAS_CDP = "18104"
CUMBY_CITY = "18128"
CUMINGS_CDP = "18134"
CUNEY_TOWN = "18152"
CUSHING_CITY = "18224"
CUT_AND_SHOOT_CITY = "18260"
CÉSAR_CHAVEZ_CDP = "14038"
DHANIS_CDP = "20248"
DISH_TOWN = "20540"
DAINGERFIELD_CITY = "18464"
DAISETTA_CITY = "18476"
DALHART_CITY = "18524"
DALLAS_CITY = "19000"
DALWORTHINGTON_GARDENS_CITY = "19084"
DAMON_CDP = "19108"
DANBURY_CITY = "19120"
DARROUZETT_TOWN = "19288"
DAWSON_TOWN = "19420"
DAYTON_LAKES_CITY = "19435"
DAYTON_CITY = "19432"
DE_KALB_CITY = "19648"
DE_LEON_CITY = "19672"
DECORDOVA_CITY = "19570"
DESOTO_CITY = "20092"
DEAN_CITY = "19456"
DEANVILLE_CDP = "19492"
DECATUR_CITY = "19528"
DEER_PARK_CITY = "19624"
DEERWOOD_CDP = "19632"
DEL_MAR_HEIGHTS_CDP = "19714"
DEL_RIO_CITY = "19792"
DEL_SOL_CDP = "19808"
DELL_CITY_CITY = "19708"
DELMITA_CDP = "19732"
DENISON_CITY = "19900"
DENNIS_CDP = "19924"
DENTON_CITY = "19972"
DENVER_CITY_TOWN = "19984"
DEPORT_CITY = "20020"
DETROIT_TOWN = "20128"
DEVERS_CITY = "20140"
DEVINE_CITY = "20152"
DEWEYVILLE_CDP = "20212"
DIBOLL_CITY = "20308"
DICKENS_CITY = "20332"
DICKINSON_CITY = "20344"
DILLEY_CITY = "20428"
DIME_BOX_CDP = "20452"
DIMMITT_CITY = "20464"
DODD_CITY_TOWN = "20680"
DODSON_TOWN = "20716"
DOFFING_CDP = "20734"
DOMINO_TOWN = "20848"
DONNA_CITY = "20884"
DOOLITTLE_CDP = "20926"
DORCHESTER_CITY = "20932"
DOUBLE_HORN_CITY = "21031"
DOUBLE_OAK_TOWN = "21028"
DOUGLASSVILLE_TOWN = "21112"
DRAPER_TOWN = "21310"
DRIFTWOOD_CDP = "21412"
DRIPPING_SPRINGS_CITY = "21424"
DRISCOLL_CITY = "21436"
DUBLIN_CITY = "21484"
DUMAS_CITY = "21556"
DUNCANVILLE_CITY = "21628"
E_LOPEZ_CDP = "23398"
EAGLE_LAKE_CITY = "21844"
EAGLE_PASS_CITY = "21892"
EARLY_CITY = "21904"
EARTH_CITY = "21928"
EAST_ALTO_BONITO_CDP = "21958"
EAST_BERNARD_CITY = "21988"
EAST_COLUMBIA_CDP = "22000"
EAST_MOUNTAIN_CITY = "22168"
EAST_TAWAKONI_CITY = "22276"
EASTLAND_CITY = "22132"
EASTON_CITY = "22192"
ECTOR_CITY = "22516"
EDCOUCH_CITY = "22528"
EDEN_CITY = "22552"
EDGECLIFF_VILLAGE_TOWN = "22588"
EDGEWATER_ESTATES_CDP = "22593"
EDGEWOOD_TOWN = "22612"
EDINBURG_CITY = "22660"
EDMONSON_TOWN = "22708"
EDNA_CITY = "22720"
EDOM_CITY = "22744"
EDROY_CDP = "22768"
EIDSON_ROAD_CDP = "22810"
EL_BRAZIL_CDP = "22853"
EL_CAMINO_ANGOSTO_CDP = "22858"
EL_CAMPO_CITY = "22864"
EL_CASTILLO_CDP = "22892"
EL_CENIZO_CDP = "22898"
EL_CENIZO_CITY = "22905"
EL_CHAPARRAL_CDP = "22920"
EL_INDIO_CDP = "23080"
EL_LAGO_CITY = "23164"
EL_MESQUITE_CDP = "23278"
EL_PASO_CITY = "24000"
EL_QUIOTE_CDP = "24013"
EL_RANCHO_VELA_CDP = "24015"
EL_REFUGIO_CDP = "24018"
EL_SOCIO_CDP = "24055"
ELBERT_CDP = "22840"
ELDORADO_CITY = "22960"
ELECTRA_CITY = "22984"
ELGIN_CITY = "23044"
ELIAS_FELA_SOLIS_CDP = "23062"
ELKHART_TOWN = "23140"
ELLINGER_CITY = "23176"
ELM_CREEK_CDP = "23254"
ELMENDORF_CITY = "23272"
ELMO_CDP = "23356"
ELSA_CITY = "24036"
EMERALD_BAY_CDP = "24158"
EMHOUSE_TOWN = "24168"
EMORY_CITY = "24216"
ENCANTADA_RANCHITO_EL_CALABOZ_CDP = "24223"
ENCHANTED_OAKS_TOWN = "24228"
ENCINAL_CITY = "24240"
ENCINO_CDP = "24252"
ENNIS_CITY = "24348"
ESCOBARES_CITY = "24552"
ESTELLINE_TOWN = "24636"
EUGENIO_SAENZ_CDP = "24738"
EULESS_CITY = "24768"
EUREKA_CITY = "24816"
EUSTACE_CITY = "24828"
EVADALE_CDP = "24840"
EVANT_TOWN = "24864"
EVERGREEN_CDP = "24894"
EVERMAN_CITY = "24912"
FABENS_CDP = "25032"
FABRICA_CDP = "25038"
FAIR_OAKS_RANCH_CITY = "25168"
FAIRCHILDS_VILLAGE = "25068"
FAIRFIELD_CITY = "25104"
FAIRVIEW_TOWN = "25224"
FALCON_HEIGHTS_CDP = "25344"
FALCON_LAKE_ESTATES_CDP = "25348"
FALCON_MESA_CDP = "25352"
FALCON_VILLAGE_CDP = "25356"
FALCONAIRE_CDP = "25338"
FALFURRIAS_CITY = "25368"
FALLS_CITY_CITY = "25392"
FALMAN_CDP = "25397"
FANNETT_CDP = "25404"
FARMERS_BRANCH_CITY = "25452"
FARMERSVILLE_CITY = "25488"
FARNSWORTH_CDP = "25512"
FARWELL_CITY = "25548"
FATE_CITY = "25572"
FAYETTEVILLE_CITY = "25644"
FERNANDO_SALINAS_CDP = "25744"
FERRIS_CITY = "25752"
FIFTH_STREET_CDP = "25795"
FLAT_CDP = "26004"
FLATONIA_TOWN = "26028"
FLOR_DEL_RIO_CDP = "26130"
FLORENCE_CITY = "26136"
FLORESVILLE_CITY = "26160"
FLOWELLA_CDP = "26220"
FLOWER_MOUND_TOWN = "26232"
FLOYDADA_CITY = "26268"
FLUVANNA_CDP = "26280"
FOLLETT_CITY = "26328"
FOREST_HEIGHTS_CDP = "26516"
FOREST_HILL_CITY = "26544"
FORNEY_CITY = "26604"
FORSAN_CITY = "26640"
FORT_BLISS_CDP = "26664"
FORT_CLARK_SPRINGS_CDP = "26680"
FORT_DAVIS_CDP = "26688"
FORT_HANCOCK_CDP = "26724"
FORT_HOOD_CDP = "26736"
FORT_STOCKTON_CITY = "26808"
FORT_WORTH_CITY = "27000"
FOUR_CORNERS_CDP = "27102"
FOUR_POINTS_CDP = "27124"
FOWLERTON_CDP = "27144"
FRANKLIN_CITY = "27288"
FRANKSTON_TOWN = "27300"
FREDERICKSBURG_CITY = "27348"
FREEPORT_CITY = "27420"
FREER_CITY = "27432"
FRESNO_CDP = "27540"
FRIENDSWOOD_CITY = "27648"
FRIONA_CITY = "27660"
FRISCO_CITY = "27684"
FRITCH_CITY = "27696"
FRONTON_CDP = "27744"
FRONTON_RANCHETTES_CDP = "27748"
FROST_CITY = "27768"
FRUITVALE_CITY = "27804"
FULSHEAR_CITY = "27876"
FULTON_TOWN = "27888"
GAIL_CDP = "27972"
GAINESVILLE_CITY = "27984"
GALENA_PARK_CITY = "27996"
GALLATIN_CITY = "28008"
GALVESTON_CITY = "28068"
GANADO_CITY = "28080"
GARCENO_CDP = "28128"
GARCIASVILLE_CDP = "28152"
GARDEN_CITY_CDP = "28176"
GARDEN_RIDGE_CITY = "28248"
GARDENDALE_CDP = "28200"
GARFIELD_CDP = "28320"
GARLAND_CITY = "29000"
GARNER_CDP = "29012"
GARRETT_TOWN = "29036"
GARRISON_CITY = "29060"
GARWOOD_CDP = "29096"
GARY_CITY_TOWN = "29108"
GARZA_SALINAS_II_CDP = "29114"
GATESVILLE_CITY = "29168"
GAUSE_CDP = "29216"
GEORGE_WEST_CITY = "29348"
GEORGETOWN_CITY = "29336"
GERONIMO_CDP = "29384"
GHOLSON_CITY = "29408"
GIDDINGS_CITY = "29432"
GILMER_CITY = "29564"
GIRARD_CDP = "29612"
GLADEWATER_CITY = "29660"
GLAZIER_CDP = "29732"
GLEN_ROSE_CITY = "29876"
GLENN_HEIGHTS_CITY = "29840"
GLIDDEN_CDP = "29912"
GODLEY_CITY = "29972"
GOLDSMITH_CITY = "30044"
GOLDTHWAITE_CITY = "30056"
GOLIAD_CITY = "30080"
GOLINDA_CITY = "30092"
GONZALES_CITY = "30116"
GOODLOW_CITY = "30188"
GOODRICH_CITY = "30224"
GORDON_CITY = "30272"
GOREE_CITY = "30296"
GORMAN_CITY = "30308"
GRAFORD_CITY = "30380"
GRAHAM_CITY = "30392"
GRANBURY_CITY = "30416"
GRAND_PRAIRIE_CITY = "30464"
GRAND_SALINE_CITY = "30476"
GRANDFALLS_TOWN = "30440"
GRANDVIEW_CITY = "30512"
GRANGER_CITY = "30548"
GRANGERLAND_CDP = "30560"
GRANITE_SHOALS_CITY = "30584"
GRANJENO_CITY = "30608"
GRAPE_CREEK_CDP = "30629"
GRAPELAND_CITY = "30632"
GRAPEVINE_CITY = "30644"
GRAYS_PRAIRIE_VILLAGE = "30752"
GREEN_VALLEY_FARMS_CDP = "30890"
GREENVILLE_CITY = "30920"
GREGORY_CITY = "31064"
GREY_FOREST_CITY = "31100"
GROESBECK_CITY = "31280"
GROOM_TOWN = "31292"
GROVES_CITY = "31328"
GROVETON_CITY = "31340"
GRUVER_CITY = "31412"
GUADALUPE_GUERRA_CDP = "31442"
GUERRA_CDP = "31484"
GUN_BARREL_CITY_CITY = "31592"
GUNTER_CITY = "31616"
GUSTINE_TOWN = "31628"
GUTHRIE_CDP = "31640"
GUTIERREZ_CDP = "31646"
H_CUELLAR_ESTATES_CDP = "32910"
HACKBERRY_TOWN = "31715"
HALE_CENTER_CITY = "31820"
HALLETTSVILLE_CITY = "31868"
HALLSBURG_CITY = "31880"
HALLSVILLE_CITY = "31904"
HALTOM_CITY_CITY = "31928"
HAMILTON_CITY = "31952"
HAMLIN_CITY = "31964"
HAMSHIRE_CDP = "32012"
HAPPY_TOWN = "32156"
HARDIN_CITY = "32240"
HARDING_GILL_TRACT_CDP = "32246"
HARGILL_CDP = "32300"
HARKER_HEIGHTS_CITY = "32312"
HARLINGEN_CITY = "32372"
HARPER_CDP = "32456"
HARROLD_CDP = "32552"
HART_CITY = "32576"
HARTLEY_CDP = "32612"
HARWOOD_TOWN = "32684"
HASKELL_CITY = "32696"
HASLET_CITY = "32720"
HAVANA_CDP = "32792"
HAWK_COVE_CITY = "32810"
HAWKINS_CITY = "32816"
HAWLEY_CITY = "32840"
HAYS_CITY = "32906"
HEARNE_CITY = "32972"
HEARTLAND_CDP = "32978"
HEATH_CITY = "32984"
HEBBRONVILLE_CDP = "33008"
HEBRON_TOWN = "33020"
HEDLEY_CITY = "33044"
HEDWIG_VILLAGE_CITY = "33068"
HEIDELBERG_CDP = "33092"
HELOTES_CITY = "33146"
HEMPHILL_CITY = "33188"
HEMPSTEAD_CITY = "33200"
HENDERSON_CITY = "33212"
HENRIETTA_CITY = "33284"
HEREFORD_CITY = "33320"
HERMLEIGH_CDP = "33356"
HEWITT_CITY = "33428"
HICKORY_CREEK_TOWN = "33476"
HICO_CITY = "33548"
HIDALGO_CITY = "33560"
HIDEAWAY_CITY = "33578"
HIGGINS_CITY = "33608"
HIGHLAND_HAVEN_CITY = "33794"
HIGHLAND_PARK_TOWN = "33824"
HIGHLAND_VILLAGE_CITY = "33848"
HIGHLANDS_CDP = "33836"
HILL_COUNTRY_VILLAGE_CITY = "33968"
HILLCREST_VILLAGE = "33980"
HILLSBORO_CITY = "34088"
HILLSIDE_ACRES_CDP = "34105"
HILLTOP_CDP_FRIO_COUNTY = "34130"
HILLTOP_CDP_STARR_COUNTY = "34133"
HILLTOP_LAKES_CDP = "34136"
HILSHIRE_VILLAGE_CITY = "34148"
HITCHCOCK_CITY = "34220"
HOLIDAY_BEACH_CDP = "34478"
HOLIDAY_LAKES_TOWN = "34502"
HOLLAND_TOWN = "34508"
HOLLIDAY_CITY = "34532"
HOLLY_LAKE_RANCH_CDP = "34586"
HOLLYWOOD_PARK_TOWN = "34628"
HOMESTEAD_MEADOWS_NORTH_CDP = "34671"
HOMESTEAD_MEADOWS_SOUTH_CDP = "34673"
HONDO_CITY = "34676"
HONEY_GROVE_CITY = "34700"
HOOKS_CITY = "34736"
HORIZON_CITY_CITY = "34832"
HORNSBY_BEND_CDP = "34856"
HORSESHOE_BAY_CITY = "34862"
HORSESHOE_BEND_CDP = "34865"
HOUSTON_CITY = "35000"
HOWARDWICK_CITY = "35072"
HOWE_TOWN = "35084"
HUBBARD_CITY = "35180"
HUCKABAY_CDP = "35204"
HUDSON_BEND_CDP = "35253"
HUDSON_OAKS_CITY = "35254"
HUDSON_CITY = "35228"
HUGHES_SPRINGS_CITY = "35300"
HULL_CDP = "35324"
HUMBLE_CITY = "35348"
HUNGERFORD_CDP = "35420"
HUNTERS_CREEK_VILLAGE_CITY = "35480"
HUNTINGTON_CITY = "35492"
HUNTSVILLE_CITY = "35528"
HURST_CITY = "35576"
HUTCHINS_CITY = "35612"
HUTTO_CITY = "35624"
HUXLEY_CITY = "35636"
IAGO_CDP = "35684"
IDALOU_CITY = "35732"
IGLESIA_ANTIGUA_CDP = "35754"
IMPACT_TOWN = "35816"
IMPERIAL_CDP = "35828"
INDIAN_HILLS_CDP = "35915"
INDIAN_LAKE_TOWN = "35918"
INDIAN_SPRINGS_CDP = "35954"
INDIO_CDP = "35966"
INDUSTRY_CITY = "35984"
INEZ_CDP = "35996"
INGLESIDE_CITY = "36008"
INGLESIDE_ON_THE_BAY_CITY = "36020"
INGRAM_CITY = "36032"
IOLA_CITY = "36068"
IOWA_COLONY_VILLAGE = "36092"
IOWA_PARK_CITY = "36104"
IRAAN_CITY = "36128"
IREDELL_CITY = "36140"
IRVING_CITY = "37000"
ITALY_TOWN = "37072"
ITASCA_CITY = "37084"
IVANHOE_CITY = "37112"
JF_VILLAREAL_CDP = "37665"
JACINTO_CITY_CITY = "37156"
JACKSBORO_CITY = "37168"
JACKSONVILLE_CITY = "37216"
JAMAICA_BEACH_CITY = "37252"
JARDIN_DE_SAN_JULIAN_CDP = "37390"
JARRELL_CITY = "37396"
JASPER_CITY = "37420"
JAYTON_CITY = "37468"
JEFFERSON_CITY = "37528"
JERSEY_VILLAGE_CITY = "37612"
JEWETT_CITY = "37648"
JOAQUIN_CITY = "37684"
JOHNSON_CITY_CITY = "37780"
JOLLY_CITY = "37924"
JONES_CREEK_VILLAGE = "37984"
JONESTOWN_CITY = "38020"
JOSEPHINE_CITY = "38068"
JOSHUA_CITY = "38080"
JOURDANTON_CITY = "38116"
JUAREZ_CDP = "38168"
JUNCTION_CITY = "38248"
JUSTIN_CITY = "38332"
K_BAR_RANCH_CDP = "38518"
KARNES_CITY_CITY = "38452"
KATY_CITY = "38476"
KAUFMAN_CITY = "38488"
KEENE_CITY = "38548"
KELLER_CITY = "38632"
KEMAH_CITY = "38776"
KEMP_CITY = "38788"
KEMPNER_CITY = "38800"
KENDLETON_CITY = "38848"
KENEDY_CITY = "38860"
KENEFICK_TOWN = "38872"
KENNARD_CITY = "38884"
KENNEDALE_CITY = "38896"
KERENS_CITY = "38992"
KERMIT_CITY = "39004"
KERRVILLE_CITY = "39040"
KILGORE_CITY = "39124"
KILLEEN_CITY = "39148"
KINGSBURY_CITY = "39292"
KINGSLAND_CDP = "39304"
KINGSVILLE_CITY = "39352"
KIRBY_CITY = "39448"
KIRBYVILLE_CITY = "39460"
KIRVIN_TOWN = "39520"
KNIPPA_CDP = "39664"
KNOLLWOOD_CITY = "39680"
KNOX_CITY_TOWN = "39700"
KOPPERL_CDP = "39784"
KOSSE_TOWN = "39844"
KOUNTZE_CITY = "39868"
KRESS_CITY = "39904"
KRUGERVILLE_CITY = "39916"
KRUM_CITY = "39928"
KURTEN_TOWN = "39940"
KYLE_CITY = "39952"
LA_BLANCA_CDP = "39988"
LA_CARLA_CDP = "39994"
LA_CASITA_CDP = "40000"
LA_CHUPAROSA_CDP = "40018"
LA_COMA_CDP = "40100"
LA_COMA_HEIGHTS_CDP = "40104"
LA_ESCONDIDA_CDP = "40186"
LA_ESPERANZA_CDP = "40188"
LA_FERIA_NORTH_CDP = "40210"
LA_FERIA_CITY = "40204"
LA_GRANGE_CITY = "40276"
LA_GRULLA_CITY = "40288"
LA_HOMA_CDP = "40342"
LA_JOYA_CITY = "40384"
LA_LOMA_DE_FALCON_CDP = "41086"
LA_MARQUE_CITY = "41116"
LA_MINITA_CDP = "41170"
LA_MOCA_RANCH_CDP = "41180"
LA_PALOMA_ADDITION_CDP = "41420"
LA_PALOMA_CDP = "41416"
LA_PALOMA_RANCHETTES_CDP = "41424"
LA_PALOMA_LOST_CREEK_CDP = "41422"
LA_PORTE_CITY = "41440"
LA_PRESA_CDP = "41449"
LA_PRYOR_CDP = "41452"
LA_PUERTA_CDP = "41458"
LA_ROSITA_CDP = "41503"
LA_TINA_RANCH_CDP = "41660"
LA_VERNIA_CITY = "41764"
LA_VICTORIA_CDP = "41782"
LA_VILLA_CITY = "41788"
LA_WARD_CITY = "41848"
LACOSTE_CITY = "40108"
LACKLAND_AFB_CDP = "40036"
LACY_LAKEVIEW_CITY = "40168"
LADONIA_TOWN = "40180"
LAGO_CDP = "40258"
LAGO_VISTA_CDP = "40262"
LAGO_VISTA_CITY = "40264"
LAGUNA_HEIGHTS_CDP = "40300"
LAGUNA_PARK_CDP = "40312"
LAGUNA_SECA_CDP = "40320"
LAGUNA_VISTA_TOWN = "40336"
LAKE_BRIDGEPORT_CITY = "40450"
LAKE_BROWNWOOD_CDP = "40456"
LAKE_BRYAN_CDP = "40462"
LAKE_CHEROKEE_CDP = "40468"
LAKE_CITY_TOWN = "40472"
LAKE_COLORADO_CITY_CDP = "40475"
LAKE_DALLAS_CITY = "40516"
LAKE_DUNLAP_CDP = "40522"
LAKE_JACKSON_CITY = "40588"
LAKE_KIOWA_CDP = "40624"
LAKE_MEDINA_SHORES_CDP = "40674"
LAKE_MEREDITH_ESTATES_CDP = "40676"
LAKE_TANGLEWOOD_VILLAGE = "40804"
LAKE_VIEW_CDP = "40966"
LAKE_WORTH_CITY = "41056"
LAKEHILLS_CDP = "40576"
LAKEPORT_CITY = "40696"
LAKESHORE_GARDENS_HIDDEN_ACRES_CDP = "40714"
LAKESIDE_CITY_TOWN = "40756"
LAKESIDE_TOWN_SAN_PATRICIO_COUNTY = "40738"
LAKESIDE_TOWN_TARRANT_COUNTY = "40744"
LAKEVIEW_TOWN = "40888"
LAKEWAY_CITY = "40984"
LAKEWOOD_VILLAGE_CITY = "41050"
LAMAR_CDP = "41092"
LAMESA_CITY = "41164"
LAMKIN_CDP = "41176"
LAMPASAS_CITY = "41188"
LANCASTER_CITY = "41212"
LANTANA_CDP = "41404"
LAREDO_RANCHETTES_CDP = "41473"
LAREDO_RANCHETTES_WEST_CDP = "41475"
LAREDO_CITY = "41464"
LAS_HACIENDAS_CDP = "41565"
LAS_LOMAS_CDP = "41566"
LAS_LOMITAS_CDP = "41569"
LAS_PALMAS_CDP = "41579"
LAS_PALMAS_II_CDP = "41580"
LAS_PILAS_CDP = "41582"
LAS_QUINTAS_FRONTERIZAS_CDP = "41583"
LASANA_CDP = "41542"
LASARA_CDP = "41548"
LATEXO_CITY = "41644"
LAUGHLIN_AFB_CDP = "41704"
LAURELES_CDP = "41728"
LAVON_CITY = "41800"
LAWN_TOWN = "41872"
LEAGUE_CITY_CITY = "41980"
LEAKEY_CITY = "42004"
LEANDER_CITY = "42016"
LEARY_CITY = "42028"
LEFORS_TOWN = "42148"
LELIA_LAKE_CDP = "42244"
LEMING_CDP = "42256"
LEON_VALLEY_CITY = "42388"
LEONA_CITY = "42340"
LEONARD_CITY = "42352"
LEROY_CITY = "42400"
LEVELLAND_CITY = "42448"
LEWISVILLE_CITY = "42508"
LEXINGTON_TOWN = "42532"
LIBERTY_CITY_CDP = "42616"
LIBERTY_HILL_CITY = "42664"
LIBERTY_CITY = "42568"
LINDALE_CITY = "42820"
LINDEN_CITY = "42844"
LINDSAY_CDP = "42874"
LINDSAY_CITY = "42868"
LINGLEVILLE_CDP = "42880"
LINN_CDP = "42916"
LIPAN_CITY = "42940"
LIPSCOMB_CDP = "42952"
LITTLE_CYPRESS_CDP = "43000"
LITTLE_ELM_CITY = "43012"
LITTLE_RIVER_ACADEMY_CITY = "43066"
LITTLEFIELD_CITY = "43024"
LIVE_OAK_CITY = "43096"
LIVERPOOL_CITY = "43120"
LIVINGSTON_TOWN = "43132"
LLANO_GRANDE_CDP = "43150"
LLANO_CITY = "43144"
LOCKETT_CDP = "43216"
LOCKHART_CITY = "43240"
LOCKNEY_TOWN = "43252"
LOG_CABIN_CITY = "43354"
LOLITA_CDP = "43432"
LOMA_GRANDE_CDP = "43458"
LOMA_LINDA_CDP = "43460"
LOMA_LINDA_EAST_CDP_JIM_WELLS_COUNTY = "43462"
LOMA_LINDA_EAST_CDP_STARR_COUNTY = "43463"
LOMA_LINDA_WEST_CDP = "43465"
LOMA_VISTA_CDP = "43474"
LOMETA_CITY = "43516"
LONE_OAK_CITY = "43636"
LONE_STAR_CITY = "43684"
LONGORIA_CDP = "43822"
LONGVIEW_CITY = "43888"
LOOP_CDP = "43948"
LOPEZVILLE_CDP = "43972"
LOPENO_CDP = "43960"
LORAINE_TOWN = "43996"
LORENA_CITY = "44020"
LORENZO_CITY = "44032"
LOS_ALTOS_CDP = "44038"
LOS_ALVAREZ_CDP = "44044"
LOS_ANGELES_CDP = "44062"
LOS_ARCOS_CDP = "44072"
LOS_ARRIEROS_CDP = "44075"
LOS_BARRERAS_CDP = "44076"
LOS_CENTENARIOS_CDP = "44077"
LOS_CORRALITOS_CDP = "44079"
LOS_EBANOS_CDP_HIDALGO_COUNTY = "44104"
LOS_EBANOS_CDP_STARR_COUNTY = "44110"
LOS_FRESNOS_CDP = "44120"
LOS_FRESNOS_CITY = "44116"
LOS_HUISACHES_CDP = "44123"
LOS_INDIOS_TOWN = "44128"
LOS_LOBOS_CDP = "44142"
LOS_MINERALES_CDP = "44145"
LOS_NOPALITOS_CDP = "44146"
LOS_VETERANOS_I_CDP = "44167"
LOS_VETERANOS_II_CDP = "44168"
LOS_YBANEZ_CITY = "44170"
LOST_CREEK_CDP = "44162"
LOTT_CITY = "44176"
LOUISE_CDP = "44212"
LOVELADY_CITY = "44260"
LOVING_CDP = "44284"
LOWRY_CROSSING_CITY = "44308"
LOZANO_CDP = "44344"
LUBBOCK_CITY = "45000"
LUCAS_CITY = "45012"
LUEDERS_CITY = "45048"
LUFKIN_CITY = "45072"
LULING_CITY = "45096"
LUMBERTON_CITY = "45120"
LYFORD_CITY = "45228"
LYONS_CDP = "45276"
LYTLE_CITY = "45288"
MABANK_TOWN = "45324"
MACDONA_CDP = "45576"
MADISONVILLE_CITY = "45996"
MAGNOLIA_BEACH_CDP = "46080"
MAGNOLIA_CITY = "46056"
MALAKOFF_CITY = "46224"
MALONE_TOWN = "46260"
MANCHACA_CDP = "46308"
MANOR_CITY = "46440"
MANSFIELD_CITY = "46452"
MANUEL_GARCIA_CDP = "46492"
MANUEL_GARCIA_II_CDP = "46494"
MANVEL_CITY = "46500"
MARATHON_CDP = "46572"
MARBLE_FALLS_CITY = "46584"
MARFA_CITY = "46620"
MARIETTA_TOWN = "46668"
MARION_CITY = "46692"
MARKHAM_CDP = "46716"
MARLIN_CITY = "46740"
MARQUEZ_CITY = "46752"
MARSHALL_CITY = "46776"
MART_CITY = "46824"
MARTINDALE_CITY = "46848"
MARTINEZ_CDP = "46854"
MASON_CITY = "46968"
MATADOR_TOWN = "47004"
MATAGORDA_CDP = "47016"
MATHIS_CITY = "47040"
MAUD_CITY = "47088"
MAURICEVILLE_CDP = "47100"
MAY_CDP = "47172"
MAYPEARL_CITY = "47268"
MCALLEN_CITY = "45384"
MCCAMEY_CITY = "45432"
MCCAULLEY_CDP = "45444"
MCDADE_CDP = "45564"
MCGREGOR_CITY = "45672"
MCKINNEY_ACRES_CDP = "45750"
MCKINNEY_CITY = "45744"
MCLEAN_TOWN = "45780"
MCLENDON_CHISHOLM_CITY = "45804"
MCLEOD_CDP = "45816"
MCQUEENEY_CDP = "45948"
MEADOW_TOWN = "47316"
MEADOWLAKES_CITY = "47330"
MEADOWS_PLACE_CITY = "47337"
MEDINA_CDP = "47406"
MEGARGEL_TOWN = "47460"
MELISSA_CITY = "47496"
MELVIN_TOWN = "47568"
MEMPHIS_CITY = "47616"
MENARD_CITY = "47628"
MENTONE_CDP = "47676"
MERCEDES_CITY = "47700"
MERIDIAN_CITY = "47760"
MERKEL_TOWN = "47796"
MERTENS_TOWN = "47820"
MERTZON_CITY = "47832"
MESQUITE_CDP = "47898"
MESQUITE_CITY = "47892"
MEXIA_CITY = "47916"
MI_RANCHITO_ESTATE_CDP = "48750"
MIAMI_CITY = "47988"
MIDFIELD_CDP = "48048"
MIDLAND_CITY = "48072"
MIDLOTHIAN_CITY = "48096"
MIDWAY_NORTH_CDP = "48272"
MIDWAY_SOUTH_CDP = "48280"
MIDWAY_CITY = "48180"
MIGUEL_BARRERA_CDP = "48315"
MIKES_CDP = "48318"
MILA_DOCE_CDP = "48320"
MILAM_CDP = "48324"
MILANO_CITY = "48336"
MILDRED_TOWN = "48372"
MILES_CITY = "48396"
MILFORD_TOWN = "48408"
MILLERS_COVE_TOWN = "48478"
MILLSAP_TOWN = "48564"
MINEOLA_CITY = "48648"
MINERAL_WELLS_CITY = "48684"
MINGUS_CITY = "48720"
MIRANDO_CITY_CDP = "48756"
MISSION_BEND_CDP = "48772"
MISSION_CITY = "48768"
MISSOURI_CITY_CITY = "48804"
MOBEETIE_CITY = "48852"
MOBILE_CITY_CITY = "48858"
MONAHANS_CITY = "48936"
MONT_BELVIEU_CITY = "49068"
MONTAGUE_CDP = "49032"
MONTE_ALTO_CDP = "49080"
MONTGOMERY_CITY = "49128"
MOODY_CITY = "49200"
MOORE_CDP = "49224"
MOORE_STATION_CITY = "49272"
MORAIDA_CDP = "49300"
MORALES_SANCHEZ_CDP = "49314"
MORAN_CITY = "49320"
MORGAN_FARM_CDP = "49359"
MORGAN_CITY = "49356"
MORGANS_POINT_RESORT_CITY = "49392"
MORGANS_POINT_CITY = "49380"
MORNING_GLORY_CDP = "49411"
MORSE_CDP = "49440"
MORTON_CITY = "49464"
MOSHEIM_CDP = "49512"
MOULTON_TOWN = "49560"
MOUND_CDP = "49572"
MOUNT_CALM_CITY = "49692"
MOUNT_ENTERPRISE_CITY = "49728"
MOUNT_PLEASANT_CITY = "49800"
MOUNT_VERNON_TOWN = "49860"
MOUNTAIN_CITY_CITY = "49600"
MUENSTER_CITY = "49932"
MULESHOE_CITY = "49968"
MULLIN_TOWN = "49992"
MUNDAY_CITY = "50040"
MUNIZ_CDP = "50058"
MURCHISON_CITY = "50076"
MURILLO_CDP = "50092"
MURPHY_CITY = "50100"
MUSTANG_RIDGE_CITY = "50200"
MUSTANG_TOWN = "50184"
MYRA_CDP = "50220"
MYRTLE_SPRINGS_CDP = "50232"
NACOGDOCHES_CITY = "50256"
NADA_CDP = "50268"
NAPLES_CITY = "50316"
NARCISO_PENA_CDP = "50322"
NASH_CITY = "50352"
NASSAU_BAY_CITY = "50376"
NATALIA_CITY = "50400"
NAVARRO_TOWN = "50448"
NAVASOTA_CITY = "50472"
NAZARETH_CITY = "50496"
NECHES_CDP = "50544"
NEDERLAND_CITY = "50580"
NEEDVILLE_CITY = "50628"
NESBITT_TOWN = "50724"
NETOS_CDP = "50742"
NEVADA_CITY = "50760"
NEW_BERLIN_CITY = "50796"
NEW_BOSTON_CITY = "50808"
NEW_BRAUNFELS_CITY = "50820"
NEW_CHAPEL_HILL_CITY = "50876"
NEW_DEAL_TOWN = "50916"
NEW_FAIRVIEW_CITY = "50920"
NEW_FALCON_CDP = "50924"
NEW_HOME_CITY = "51012"
NEW_HOPE_TOWN = "51036"
NEW_LONDON_CITY = "51168"
NEW_SUMMERFIELD_CITY = "51336"
NEW_ULM_CDP = "51384"
NEW_WAVERLY_CITY = "51396"
NEWARK_CITY = "50772"
NEWCASTLE_CITY = "50868"
NEWTON_CITY = "51372"
NEYLANDVILLE_TOWN = "51444"
NIEDERWALD_CITY = "51492"
NINA_CDP = "51552"
NIXON_CITY = "51588"
NOCONA_HILLS_CDP = "51654"
NOCONA_CITY = "51648"
NOLANVILLE_CITY = "51708"
NOME_CITY = "51720"
NOONDAY_CITY = "51756"
NORDHEIM_CITY = "51792"
NORMANDY_CDP = "51828"
NORMANGEE_TOWN = "51840"
NORMANNA_CDP = "51852"
NORTH_ALAMO_CDP = "51900"
NORTH_CLEVELAND_CITY = "51984"
NORTH_ESCOBARES_CDP = "52068"
NORTH_PEARSALL_CDP = "52302"
NORTH_RICHLAND_HILLS_CITY = "52356"
NORTH_SAN_PEDRO_CDP = "52404"
NORTHLAKE_TOWN = "52212"
NOVICE_CITY = "52668"
OBRIEN_CITY = "53304"
ODONNELL_CITY = "53436"
OAK_GROVE_TOWN = "52902"
OAK_ISLAND_CDP = "53004"
OAK_LEAF_CITY = "53115"
OAK_POINT_CITY = "53130"
OAK_RIDGE_NORTH_CITY = "53190"
OAK_RIDGE_TOWN_COOKE_COUNTY = "53154"
OAK_RIDGE_TOWN_KAUFMAN_COUNTY = "53160"
OAK_TRAIL_SHORES_CDP = "53212"
OAK_VALLEY_TOWN = "53217"
OAKHURST_CDP = "52992"
OAKWOOD_TOWN = "53232"
ODEM_CITY = "53376"
ODESSA_CITY = "53388"
OGLESBY_CITY = "53520"
OILTON_CDP = "53556"
OKLAUNION_CDP = "53616"
OLD_RIVER_WINFREE_CITY = "53824"
OLIVAREZ_CDP = "53934"
OLIVIA_LOPEZ_DE_GUTIERREZ_CDP = "53946"
OLMITO_CDP = "53964"
OLMITO_AND_OLMITO_CDP = "53970"
OLMOS_PARK_CITY = "53988"
OLNEY_CITY = "54000"
OLTON_CITY = "54012"
OMAHA_CITY = "54024"
ONALASKA_CITY = "54048"
OPDYKE_WEST_TOWN = "54075"
ORANGE_GROVE_CITY = "54168"
ORANGE_CITY = "54132"
ORASON_CDP = "54186"
ORCHARD_CITY = "54192"
ORE_CITY_CITY = "54216"
OVERTON_CITY = "54432"
OVILLA_CITY = "54444"
OWL_RANCH_CDP = "54509"
OYSTER_CREEK_CITY = "54528"
OZONA_CDP = "54552"
PABLO_PENA_CDP = "54558"
PADUCAH_TOWN = "54600"
PAIGE_CDP = "54624"
PAINT_ROCK_TOWN = "54636"
PAISANO_PARK_CDP = "54666"
PALACIOS_CITY = "54684"
PALESTINE_CITY = "54708"
PALISADES_VILLAGE = "54726"
PALM_VALLEY_CITY = "54798"
PALMER_CDP = "54748"
PALMER_TOWN = "54744"
PALMHURST_CITY = "54780"
PALMVIEW_SOUTH_CDP = "54810"
PALMVIEW_CITY = "54804"
PALO_BLANCO_CDP = "54846"
PALO_PINTO_CDP = "54876"
PALOMA_CREEK_CDP = "54868"
PALOMA_CREEK_SOUTH_CDP = "54872"
PAMPA_CITY = "54912"
PANHANDLE_TOWN = "54960"
PANORAMA_VILLAGE_CITY = "55008"
PANTEGO_TOWN = "55020"
PARADISE_CITY = "55056"
PARIS_CITY = "55080"
PARKER_CITY = "55152"
PASADENA_CITY = "56000"
PATTISON_CITY = "56108"
PATTON_VILLAGE_CITY = "56156"
PAWNEE_CDP = "56252"
PAYNE_SPRINGS_TOWN = "56276"
PEARLAND_CITY = "56348"
PEARSALL_CITY = "56384"
PECAN_ACRES_CDP = "56462"
PECAN_GAP_CITY = "56468"
PECAN_GROVE_CDP = "56482"
PECAN_HILL_CITY = "56485"
PECAN_PLANTATION_CDP = "56498"
PELICAN_BAY_CITY = "56640"
PENA_CDP = "56644"
PENDLETON_CDP = "56660"
PENELOPE_TOWN = "56672"
PENITAS_CITY = "56696"
PEREZVILLE_CDP = "56804"
PERRIN_CDP = "56864"
PERRYTON_CITY = "56912"
PETERSBURG_CITY = "56996"
PETROLIA_CITY = "57044"
PETRONILA_CITY = "57056"
PETTUS_CDP = "57116"
PETTY_CDP = "57128"
PFLUGERVILLE_CITY = "57176"
PHARR_CITY = "57200"
PILOT_POINT_CITY = "57476"
PINE_FOREST_CITY = "57524"
PINE_HARBOR_CDP = "57566"
PINE_ISLAND_TOWN = "57615"
PINEBROOK_CDP = "57494"
PINEHURST_CDP = "57596"
PINEHURST_CITY = "57608"
PINELAND_CITY = "57644"
PINEWOOD_ESTATES_CDP = "57752"
PINEY_POINT_VILLAGE_CITY = "57800"
PITTSBURG_CITY = "57908"
PLACEDO_CDP = "57932"
PLAINS_TOWN = "57968"
PLAINVIEW_CITY = "57980"
PLANO_CITY = "58016"
PLANTERSVILLE_CITY = "58040"
PLEAK_VILLAGE = "58088"
PLEASANT_HILL_CDP = "58232"
PLEASANT_VALLEY_TOWN = "58400"
PLEASANTON_CITY = "58280"
PLUM_CDP = "58436"
PLUM_GROVE_CITY = "58448"
POETRY_TOWN = "58502"
POINT_BLANK_CITY = "58556"
POINT_COMFORT_CITY = "58568"
POINT_VENTURE_VILLAGE = "58586"
POINT_CITY = "58532"
PONDER_TOWN = "58664"
PORT_ARANSAS_CITY = "58808"
PORT_ARTHUR_CITY = "58820"
PORT_ISABEL_CITY = "58892"
PORT_LAVACA_CITY = "58916"
PORT_MANSFIELD_CDP = "58928"
PORT_NECHES_CITY = "58940"
PORT_OCONNOR_CDP = "58952"
PORTER_HEIGHTS_CDP = "58850"
PORTLAND_CITY = "58904"
POST_OAK_BEND_CITY_TOWN = "59066"
POST_CITY = "59012"
POTEET_CITY = "59084"
POTH_TOWN = "59096"
POTOSI_CDP = "59108"
POTTSBORO_TOWN = "59132"
POWDERLY_CDP = "59156"
POWELL_TOWN = "59168"
POYNOR_TOWN = "59192"
PRADO_VERDE_CDP = "59210"
PRAESEL_CDP = "59216"
PRAIRIE_VIEW_CITY = "59336"
PREMONT_CITY = "59384"
PRESIDIO_CITY = "59396"
PRESTON_CDP = "59420"
PRIDDY_CDP = "59528"
PRIMERA_TOWN = "59540"
PRINCETON_CITY = "59576"
PROCTOR_CDP = "59612"
PROGRESO_LAKES_CITY = "59642"
PROGRESO_CITY = "59636"
PROSPER_TOWN = "59696"
PROVIDENCE_VILLAGE_TOWN = "59748"
PUEBLO_EAST_CDP = "59794"
PUEBLO_NUEVO_CDP = "59798"
PUTNAM_TOWN = "59984"
PYOTE_TOWN = "59996"
QUAIL_CDP = "60020"
QUAIL_CREEK_CDP = "60026"
QUANAH_CITY = "60044"
QUEEN_CITY_CITY = "60080"
QUEMADO_CDP = "60092"
QUESADA_CDP = "60098"
QUINLAN_CITY = "60140"
QUINTANA_TOWN = "60164"
QUITAQUE_CITY = "60176"
QUITMAN_CITY = "60188"
RADAR_BASE_CDP = "60278"
RAFAEL_PENA_CDP = "60290"
RALLS_CITY = "60356"
RAMIRENO_CDP = "60380"
RAMIREZ_PEREZ_CDP = "60408"
RAMOS_CDP = "60422"
RANCHETTE_ESTATES_CDP = "60458"
RANCHITOS_EAST_CDP = "60480"
RANCHITOS_LAS_LOMAS_CDP = "60482"
RANCHITOS_DEL_NORTE_CDP = "60478"
RANCHO_ALEGRE_CDP = "60518"
RANCHO_BANQUETE_CDP = "60529"
RANCHO_CHICO_CDP = "60534"
RANCHO_VIEJO_CDP = "60554"
RANCHO_VIEJO_TOWN = "60544"
RANCHOS_PENITAS_WEST_CDP = "60539"
RANDOLPH_AFB_CDP = "60608"
RANGER_CITY = "60632"
RANGERVILLE_VILLAGE = "60644"
RANKIN_CITY = "60668"
RANSOM_CANYON_TOWN = "60672"
RATAMOSA_CDP = "60686"
RAVENNA_CITY = "60752"
RAYMONDVILLE_CITY = "60836"
REALITOS_CDP = "60932"
RED_LICK_CITY = "61172"
RED_OAK_CITY = "61196"
RED_ROCK_CDP = "61280"
REDFIELD_CDP = "61040"
REDFORD_CDP = "61076"
REDLAND_CDP = "61124"
REDWATER_CITY = "61340"
REDWOOD_CDP = "61352"
REFUGIO_TOWN = "61436"
REGINO_RAMIREZ_CDP = "61454"
REID_HOPE_KING_CDP = "61466"
REKLAW_CITY = "61508"
RELAMPAGO_CDP = "61532"
RENDON_CDP = "61568"
RENO_CITY_LAMAR_COUNTY = "61592"
RENO_CITY_PARKER_AND_TARRANT_COUNTIES = "61604"
RETREAT_TOWN = "61616"
RHOME_CITY = "61700"
RICARDO_CDP = "61724"
RICE_TRACTS_CDP = "61766"
RICE_CITY = "61736"
RICHARDS_CDP = "61784"
RICHARDSON_CITY = "61796"
RICHLAND_HILLS_CITY = "61844"
RICHLAND_SPRINGS_TOWN = "61880"
RICHLAND_TOWN = "61820"
RICHMOND_CITY = "61892"
RICHWOOD_CITY = "61904"
RIESEL_CITY = "62108"
RINGGOLD_CDP = "62132"
RIO_BRAVO_CITY = "62138"
RIO_GRANDE_CITY_CITY = "62168"
RIO_HONDO_CITY = "62180"
RIO_VISTA_CITY = "62240"
RISING_STAR_TOWN = "62252"
RIVER_OAKS_CITY = "62384"
RIVERENO_CDP = "62318"
RIVERSIDE_CITY = "62408"
RIVIERA_CDP = "62468"
ROAD_RUNNER_TOWN = "62486"
ROANOKE_CITY = "62504"
ROARING_SPRINGS_TOWN = "62528"
ROBERT_LEE_CITY = "62564"
ROBINSON_CITY = "62588"
ROBSTOWN_CITY = "62600"
ROBY_CITY = "62612"
ROCHELLE_CDP = "62624"
ROCHESTER_TOWN = "62636"
ROCK_ISLAND_CDP = "62732"
ROCKDALE_CITY = "62672"
ROCKPORT_CITY = "62804"
ROCKSPRINGS_TOWN = "62816"
ROCKWALL_CITY = "62828"
ROCKWELL_PLACE_CDP = "62834"
ROCKY_MOUND_TOWN = "62870"
ROGERS_TOWN = "62924"
ROLLINGWOOD_CITY = "63008"
ROMA_CITY = "63020"
ROMAN_FOREST_CITY = "63044"
ROPESVILLE_CITY = "63140"
ROSANKY_CDP = "63164"
ROSCOE_CITY = "63176"
ROSE_CITY_CITY = "63200"
ROSE_HILL_ACRES_CITY = "63272"
ROSEBUD_CITY = "63188"
ROSENBERG_CITY = "63284"
ROSHARON_CDP = "63332"
ROSITA_CDP = "63350"
ROSS_CITY = "63380"
ROSSER_VILLAGE = "63404"
ROTAN_CITY = "63464"
ROUND_MOUNTAIN_TOWN = "63476"
ROUND_ROCK_CITY = "63500"
ROUND_TOP_TOWN = "63524"
ROWENA_CDP = "63560"
ROWLETT_CITY = "63572"
ROXTON_CITY = "63584"
ROYSE_CITY_CITY = "63668"
RULE_TOWN = "63752"
RUNAWAY_BAY_CITY = "63782"
RUNGE_TOWN = "63788"
RUSK_CITY = "63848"
SABINAL_CITY = "64004"
SACHSE_CITY = "64064"
SADLER_CITY = "64088"
SAGINAW_CITY = "64112"
SALADO_VILLAGE = "64268"
SALIDA_DEL_SOL_ESTATES_CDP = "64307"
SALINENO_CDP = "64316"
SALINENO_NORTH_CDP = "64322"
SAM_RAYBURN_CDP = "64460"
SAMMY_MARTINEZ_CDP = "64442"
SAMNORWOOD_CDP = "64448"
SAN_ANGELO_CITY = "64472"
SAN_ANTONIO_CITY = "65000"
SAN_AUGUSTINE_CITY = "65024"
SAN_BENITO_CITY = "65036"
SAN_CARLOS_CDP = "65048"
SAN_CARLOS_I_CDP = "65049"
SAN_CARLOS_II_CDP = "65050"
SAN_DIEGO_CITY = "65180"
SAN_ELIZARIO_CITY = "65360"
SAN_FELIPE_TOWN = "65372"
SAN_FERNANDO_CDP = "65378"
SAN_ISIDRO_CDP = "65432"
SAN_JUAN_CDP = "65532"
SAN_JUAN_CITY = "65516"
SAN_LEANNA_VILLAGE = "65552"
SAN_LEON_CDP = "65564"
SAN_MARCOS_CITY = "65600"
SAN_PATRICIO_CITY = "65612"
SAN_PEDRO_CDP = "65620"
SAN_PERLITA_CITY = "65636"
SAN_SABA_CITY = "65648"
SAN_YGNACIO_CDP = "65792"
SANCTUARY_TOWN = "65066"
SAND_SPRINGS_CDP = "65240"
SANDERSON_CDP = "65084"
SANDIA_CDP = "65168"
SANDOVAL_CDP = "65210"
SANDY_HOLLOW_ESCONDIDAS_CDP = "65342"
SANDY_OAKS_CITY = "65344"
SANDY_POINT_CITY = "65345"
SANFORD_TOWN = "65384"
SANGER_CITY = "65408"
SANSOM_PARK_CITY = "65660"
SANTA_ANNA_CDP = "65678"
SANTA_ANNA_TOWN = "65672"
SANTA_CLARA_CITY = "65690"
SANTA_CRUZ_CDP = "65708"
SANTA_FE_CITY = "65726"
SANTA_MARIA_CDP = "65744"
SANTA_MONICA_CDP = "65756"
SANTA_RITA_RANCH_CDP = "65762"
SANTA_ROSA_CDP = "65774"
SANTA_ROSA_TOWN = "65768"
SANTEL_CDP = "65777"
SANTO_CDP = "65780"
SARGENT_CDP = "65864"
SARITA_CDP = "65876"
SAVANNAH_CDP = "66000"
SAVOY_CITY = "66008"
SCENIC_OAKS_CDP = "66089"
SCHERTZ_CITY = "66128"
SCHULENBURG_CITY = "66188"
SCISSORS_CDP = "66248"
SCOTLAND_CITY = "66284"
SCOTTSVILLE_CITY = "66332"
SCURRY_TOWN = "66368"
SEABROOK_CITY = "66392"
SEADRIFT_CITY = "66416"
SEAGOVILLE_CITY = "66428"
SEAGRAVES_CITY = "66440"
SEALY_CITY = "66464"
SEBASTIAN_CDP = "66512"
SECO_MINES_CDP = "66536"
SEGUIN_CITY = "66644"
SEIS_LAGOS_CDP = "66686"
SELMA_CITY = "66704"
SEMINOLE_CITY = "66764"
SERENADA_CDP = "66806"
SETH_WARD_CDP = "66848"
SEVEN_OAKS_CITY = "66884"
SEVEN_POINTS_CITY = "66908"
SEYMOUR_CITY = "66968"
SHADY_HOLLOW_CDP = "67082"
SHADY_SHORES_TOWN = "67100"
SHADYBROOK_CDP = "67010"
SHALLOWATER_CITY = "67136"
SHAMROCK_CITY = "67160"
SHAVANO_PARK_CITY = "67268"
SHEFFIELD_CDP = "67340"
SHELBYVILLE_CDP = "67364"
SHELDON_CDP = "67376"
SHENANDOAH_CITY = "67400"
SHEPHERD_CITY = "67424"
SHERIDAN_CDP = "67472"
SHERMAN_CITY = "67496"
SHERWOOD_SHORES_CDP = "67554"
SHINER_CITY = "67640"
SHIRO_CDP = "67664"
SHOREACRES_CITY = "67688"
SIENNA_CDP = "67763"
SIERRA_BLANCA_CDP = "67772"
SIESTA_ACRES_CDP = "67775"
SIESTA_SHORES_CDP = "67778"
SILSBEE_CITY = "67832"
SILVERTON_CITY = "67904"
SIMONTON_CITY = "67964"
SINTON_CITY = "68036"
SKELLYTOWN_TOWN = "68120"
SKIDMORE_CDP = "68132"
SLATON_CITY = "68180"
SMILEY_CITY = "68300"
SMITHVILLE_CITY = "68456"
SMYER_TOWN = "68504"
SNOOK_CITY = "68576"
SNYDER_CITY = "68624"
SOCORRO_CITY = "68636"
SOLIS_CDP = "68678"
SOMERSET_CITY = "68708"
SOMERVILLE_CITY = "68720"
SONORA_CITY = "68756"
SONTERRA_CDP = "68762"
SOUR_LAKE_CITY = "68828"
SOUTH_ALAMO_CDP = "68846"
SOUTH_FORK_ESTATES_CDP = "68966"
SOUTH_FRYDEK_CITY = "68978"
SOUTH_HOUSTON_CITY = "69020"
SOUTH_LA_PALOMA_CDP = "69072"
SOUTH_MOUNTAIN_TOWN = "69120"
SOUTH_PADRE_ISLAND_TOWN = "69140"
SOUTH_POINT_CDP = "69194"
SOUTH_TOLEDO_BEND_CDP = "69326"
SOUTHLAKE_CITY = "69032"
SOUTHMAYD_CITY = "69104"
SOUTHSIDE_PLACE_CITY = "69272"
SOUTHWEST_SANDHILL_CDP = "69353"
SPADE_CDP = "69380"
SPARKS_CDP = "69432"
SPEARMAN_CITY = "69476"
SPLENDORA_CITY = "69548"
SPOFFORD_CITY = "69560"
SPRING_BRANCH_CITY = "69608"
SPRING_CDP = "69596"
SPRING_GARDENS_CDP = "69708"
SPRING_VALLEY_VILLAGE_CITY = "69830"
SPRINGLAKE_TOWN = "69764"
SPRINGTOWN_CITY = "69800"
SPUR_CITY = "69848"
ST_HEDWIG_TOWN = "64172"
ST_JO_CITY = "64184"
ST_PAUL_CDP = "64244"
ST_PAUL_TOWN = "64220"
STAFFORD_CITY = "69908"
STAGECOACH_TOWN = "69932"
STAMFORD_CITY = "69980"
STANTON_CITY = "70040"
STAPLES_CITY = "70052"
STAR_HARBOR_CITY = "70076"
STEINER_RANCH_CDP = "70154"
STEPHENVILLE_CITY = "70208"
STERLING_CITY_CITY = "70232"
STINNETT_CITY = "70340"
STOCKDALE_CITY = "70376"
STOCKTON_BEND_CITY = "70406"
STONEWALL_CDP = "70460"
STOWELL_CDP = "70520"
STRATFORD_CITY = "70544"
STRAWN_CITY = "70580"
STREETMAN_TOWN = "70604"
STUDY_BUTTE_CDP = "70688"
SUDAN_CITY = "70772"
SUGAR_LAND_CITY = "70808"
SULLIVAN_CITY_CITY = "70868"
SULPHUR_SPRINGS_CITY = "70904"
SUMMERFIELD_CDP = "70940"
SUN_VALLEY_CITY = "71356"
SUNDOWN_CITY = "71060"
SUNNYVALE_TOWN = "71156"
SUNRAY_CITY = "71180"
SUNRISE_BEACH_VILLAGE_CITY = "71228"
SUNRISE_SHORES_CDP = "71236"
SUNSET_ACRES_CDP = "71289"
SUNSET_CDP_MONTAGUE_COUNTY = "71264"
SUNSET_CDP_STARR_COUNTY = "71274"
SUNSET_VALLEY_CITY = "71324"
SURFSIDE_BEACH_CITY = "71384"
SWEENY_CITY = "71492"
SWEETWATER_CITY = "71540"
SYLVESTER_CDP = "71636"
TAFT_SOUTHWEST_CDP = "71696"
TAFT_CITY = "71684"
TAHOKA_CITY = "71708"
TALCO_CITY = "71732"
TALTY_TOWN = "71756"
TANQUECITOS_SOUTH_ACRES_CDP = "71820"
TANQUECITOS_SOUTH_ACRES_II_CDP = "71824"
TATUM_CITY = "71924"
TAYLOR_LAKE_VILLAGE_CITY = "71960"
TAYLOR_LANDING_CITY = "71966"
TAYLOR_CITY = "71948"
TEAGUE_CITY = "72020"
TEHUACANA_TOWN = "72080"
TEMPLE_CITY = "72176"
TENAHA_TOWN = "72188"
TERLINGUA_CDP = "72248"
TERRELL_HILLS_CITY = "72296"
TERRELL_CITY = "72284"
TEXARKANA_CITY = "72368"
TEXAS_CITY_CITY = "72392"
TEXHOMA_CITY = "72464"
TEXLINE_TOWN = "72476"
THE_COLONY_CITY = "72530"
THE_HILLS_VILLAGE = "72578"
THE_HOMESTEADS_CDP = "72581"
THE_WOODLANDS_CDP = "72656"
THOMPSONS_TOWN = "72740"
THOMPSONVILLE_CDP = "72758"
THORNDALE_CITY = "72776"
THORNTON_TOWN = "72788"
THORNTONVILLE_TOWN = "72800"
THRALL_CITY = "72824"
THREE_RIVERS_CITY = "72872"
THROCKMORTON_TOWN = "72896"
THUNDERBIRD_BAY_CDP = "72902"
TIERRA_BONITA_CDP = "72948"
TIERRA_DORADA_CDP = "72950"
TIERRA_GRANDE_CDP = "72952"
TIERRA_VERDE_CDP = "72954"
TIKI_ISLAND_VILLAGE = "72989"
TILDEN_CDP = "72992"
TIMBERCREEK_CANYON_VILLAGE = "73030"
TIMBERWOOD_PARK_CDP = "73057"
TIMPSON_CITY = "73076"
TIOGA_TOWN = "73112"
TIRA_TOWN = "73124"
TIVOLI_CDP = "73148"
TOCO_CITY = "73196"
TODD_MISSION_CITY = "73224"
TOLAR_CITY = "73268"
TOM_BEAN_CITY = "73328"
TOMBALL_CITY = "73316"
TOOL_CITY = "73352"
TORNILLO_CDP = "73376"
TOW_CDP = "73424"
TOWN_OF_PECOS_CITY = "73493"
TOYAH_TOWN = "73496"
TRADEWINDS_CDP = "73526"
TRAVIS_RANCH_CDP = "73562"
TRENT_TOWN = "73580"
TRENTON_CITY = "73592"
TRINIDAD_CITY = "73652"
TRINITY_CITY = "73664"
TROPHY_CLUB_TOWN = "73710"
TROUP_CITY = "73724"
TROY_CITY = "73748"
TULETA_CDP = "73856"
TULIA_CITY = "73868"
TULSITA_CDP = "73904"
TUNIS_CDP = "73928"
TURKEY_CITY = "73964"
TUSCOLA_CITY = "74048"
TYE_CITY = "74132"
TYLER_CITY = "74144"
TYNAN_CDP = "74168"
UHLAND_CITY = "74216"
UMBARGER_CDP = "74228"
UNCERTAIN_CITY = "74240"
UNION_GROVE_CITY = "74312"
UNION_VALLEY_CITY = "74372"
UNIVERSAL_CITY_CITY = "74408"
UNIVERSITY_PARK_CITY = "74492"
UTOPIA_CDP = "74576"
UVALDE_ESTATES_CDP = "74594"
UVALDE_CITY = "74588"
VAL_VERDE_PARK_CDP = "74895"
VALENTINE_TOWN = "74648"
VALERA_CDP = "74660"
VALLE_HERMOSO_CDP = "74667"
VALLE_VERDE_CDP = "74668"
VALLE_VISTA_CDP = "74670"
VALLEY_MILLS_CITY = "74732"
VALLEY_VIEW_CITY = "74756"
VAN_ALSTYNE_CITY = "74924"
VAN_HORN_TOWN = "75032"
VAN_VLECK_CDP = "75068"
VAN_CITY = "74912"
VANDERBILT_CDP = "74984"
VEGA_CITY = "75188"
VENUS_TOWN = "75236"
VERNON_CITY = "75308"
VICTORIA_VERA_CDP = "75432"
VICTORIA_CITY = "75428"
VIDOR_CITY = "75476"
VILLA_PANCHO_CDP = "75614"
VILLA_VERDE_CDP = "75626"
VILLA_DEL_SOL_CDP = "75554"
VILLARREAL_CDP = "75617"
VINTON_VILLAGE = "75668"
VOLENTE_VILLAGE = "75752"
VON_ORMY_CITY = "75764"
WACO_CITY = "76000"
WADSWORTH_CDP = "76012"
WAELDER_CITY = "76024"
WAKA_CDP = "76048"
WAKE_VILLAGE_CITY = "76096"
WALLER_CITY = "76228"
WALLIS_CITY = "76240"
WALNUT_SPRINGS_CITY = "76348"
WARREN_CDP = "76564"
WARREN_CITY_CITY = "76576"
WASHBURN_CDP = "76612"
WASKOM_CITY = "76636"
WATAUGA_CITY = "76672"
WAXAHACHIE_CITY = "76816"
WEATHERFORD_CITY = "76864"
WEBBERVILLE_VILLAGE = "76924"
WEBSTER_CITY = "76948"
WEIMAR_CITY = "77020"
WEINERT_CITY = "77044"
WEIR_CITY = "77056"
WELCH_CDP = "77080"
WELLINGTON_CITY = "77152"
WELLMAN_CITY = "77164"
WELLS_BRANCH_CDP = "77196"
WELLS_TOWN = "77176"
WESLACO_CITY = "77272"
WEST_ALTO_BONITO_CDP = "77336"
WEST_COLUMBIA_CITY = "77416"
WEST_LAKE_HILLS_CITY = "77632"
WEST_LIVINGSTON_CDP = "77662"
WEST_ODESSA_CDP = "77728"
WEST_ORANGE_CITY = "77752"
WEST_SHARYLAND_CDP = "77866"
WEST_TAWAKONI_CITY = "77896"
WEST_UNIVERSITY_PLACE_CITY = "77956"
WEST_CITY = "77332"
WESTBROOK_CITY = "77380"
WESTDALE_CDP = "77422"
WESTERN_LAKE_CDP = "77490"
WESTLAKE_TOWN = "77620"
WESTMINSTER_CDP = "77680"
WESTON_LAKES_CITY = "77746"
WESTON_CITY = "77740"
WESTOVER_HILLS_TOWN = "77788"
WESTWAY_CDP = "78016"
WESTWOOD_SHORES_CDP = "78040"
WESTWORTH_VILLAGE_CITY = "78076"
WHARTON_CITY = "78136"
WHEELER_CITY = "78208"
WHITE_DEER_TOWN = "78316"
WHITE_OAK_CITY = "78436"
WHITE_SETTLEMENT_CITY = "78544"
WHITEFACE_TOWN = "78328"
WHITEHOUSE_CITY = "78388"
WHITESBORO_CITY = "78532"
WHITEWRIGHT_TOWN = "78628"
WHITHARRAL_CDP = "78640"
WHITNEY_TOWN = "78664"
WICHITA_FALLS_CITY = "79000"
WICKETT_TOWN = "79036"
WILD_PEACH_VILLAGE_CDP = "79192"
WILDORADO_CDP = "79180"
WILDWOOD_CDP = "79204"
WILLIS_CITY = "79408"
WILLOW_GROVE_CDP = "79456"
WILLOW_PARK_CITY = "79492"
WILLS_POINT_CITY = "79564"
WILMER_CITY = "79576"
WILSON_CITY = "79612"
WIMBERLEY_CITY = "79624"
WINDCREST_CITY = "79672"
WINDOM_TOWN = "79684"
WINDTHORST_TOWN = "79696"
WINFIELD_CITY = "79720"
WINGATE_CDP = "79756"
WINK_CITY = "79768"
WINNIE_CDP = "79792"
WINNSBORO_CITY = "79816"
WINONA_TOWN = "79828"
WINTERS_CITY = "79876"
WIXON_VALLEY_CITY = "79919"
WOLFE_CITY_CITY = "79948"
WOLFFORTH_CITY = "79972"
WOODBRANCH_CITY = "80044"
WOODCREEK_CITY = "80058"
WOODLOCH_TOWN = "80144"
WOODSBORO_TOWN = "80176"
WOODSON_TOWN = "80188"
WOODVILLE_TOWN = "80212"
WOODWAY_CITY = "80224"
WORTHAM_TOWN = "80296"
WYLDWOOD_CDP = "80350"
WYLIE_CITY = "80356"
YANCEY_CDP = "80428"
YANTIS_TOWN = "80440"
YOAKUM_CITY = "80560"
YORKTOWN_CITY = "80584"
YZNAGA_CDP = "80686"
ZAPATA_CDP = "80716"
ZAPATA_RANCH_CDP = "80722"
ZARATE_CDP = "80724"
ZAVALLA_CITY = "80728"
ZEPHYR_CDP = "80740"
ZUEHL_CDP = "80836"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Colorado."""


ACRES_GREEN_CDP = "00320"
AETNA_ESTATES_CDP = "00620"
AGUILAR_TOWN = "00760"
AIR_FORCE_ACADEMY_CDP = "00870"
AKRON_TOWN = "00925"
ALAMOSA_EAST_CDP = "01145"
ALAMOSA_CITY = "01090"
ALLENSPARK_CDP = "01420"
ALMA_TOWN = "01530"
ALPINE_CDP = "01640"
ALTONA_CDP = "01740"
AMHERST_CDP = "01915"
ANTONITO_TOWN = "02355"
APPLEWOOD_CDP = "02575"
ARAPAHOE_CDP = "02850"
ARBOLES_CDP = "02905"
ARISTOCRAT_RANCHETTES_CDP = "03015"
ARRIBA_TOWN = "03235"
ARVADA_CITY = "03455"
ASPEN_PARK_CDP = "03730"
ASPEN_CITY = "03620"
ATWOOD_CDP = "03840"
AULT_TOWN = "03950"
AURORA_CITY = "04000"
AVON_TOWN = "04110"
AVONDALE_CDP = "04165"
BARK_RANCH_CDP = "04620"
BASALT_TOWN = "04935"
BATTLEMENT_MESA_CDP = "05120"
BAYFIELD_TOWN = "05265"
BENNETT_TOWN = "06090"
BERKLEY_CDP = "06172"
BERTHOUD_TOWN = "06255"
BETHUNE_TOWN = "06530"
BEULAH_VALLEY_CDP = "06602"
BLACK_FOREST_CDP = "06970"
BLACK_HAWK_CITY = "07025"
BLANCA_TOWN = "07190"
BLENDE_CDP = "07245"
BLUE_RIVER_TOWN = "07410"
BLUE_SKY_CDP = "07420"
BLUE_VALLEY_CDP = "07455"
BONANZA_MOUNTAIN_ESTATES_CDP = "07580"
BONANZA_TOWN = "07571"
BOONE_TOWN = "07795"
BOULDER_CITY = "07850"
BOW_MAR_TOWN = "08070"
BRANDON_CDP = "08290"
BRANSON_TOWN = "08345"
BRECKENRIDGE_TOWN = "08400"
BRICK_CENTER_CDP = "08530"
BRIGGSDALE_CDP = "08620"
BRIGHTON_CITY = "08675"
BROOK_FOREST_CDP = "08950"
BROOKSIDE_TOWN = "09115"
BROOMFIELD_CITY = "09280"
BRUSH_CITY = "09555"
BUENA_VISTA_TOWN = "10105"
BURLINGTON_CITY = "10600"
BYERS_CDP = "10985"
CALHAN_TOWN = "11260"
CAMPO_TOWN = "11645"
CAPULIN_CDP = "11975"
CARBONATE_TOWN = "12030"
CARBONDALE_TOWN = "12045"
CASCADE_CHIPITA_PARK_CDP = "12325"
CASTLE_PINES_VILLAGE_CDP = "12393"
CASTLE_PINES_CITY = "12387"
CASTLE_ROCK_TOWN = "12415"
CATHEDRAL_CDP = "12450"
CATHERINE_CDP = "12460"
CATTLE_CREEK_CDP = "12470"
CANON_CITY_CITY = "11810"
CEDAREDGE_TOWN = "12635"
CENTENNIAL_CITY = "12815"
CENTER_TOWN = "12855"
CENTRAL_CITY_CITY = "12910"
CHACRA_CDP = "12945"
CHERAW_TOWN = "13460"
CHERRY_CREEK_CDP = "13590"
CHERRY_HILLS_VILLAGE_CITY = "13845"
CHEYENNE_WELLS_TOWN = "14175"
CIMARRON_HILLS_CDP = "14587"
CITY_OF_CREEDE_TOWN = "14765"
CLIFTON_CDP = "15165"
COAL_CREEK_CDP = "15302"
COAL_CREEK_TOWN = "15330"
COALDALE_CDP = "15440"
COKEDALE_TOWN = "15550"
COLLBRAN_TOWN = "15605"
COLONA_CDP = "15825"
COLORADO_CITY_CDP = "15935"
COLORADO_SPRINGS_CITY = "16000"
COLUMBINE_CDP = "16110"
COLUMBINE_VALLEY_TOWN = "16385"
COMANCHE_CREEK_CDP = "16465"
COMMERCE_CITY_CITY = "16495"
CONEJOS_CDP = "16715"
COPE_CDP = "17100"
COPPER_MOUNTAIN_CDP = "17150"
CORTEZ_CITY = "17375"
COTOPAXI_CDP = "17485"
CRAIG_CITY = "17760"
CRAWFORD_TOWN = "17925"
CRESTED_BUTTE_TOWN = "18310"
CRESTONE_TOWN = "18420"
CRIPPLE_CREEK_CITY = "18530"
CRISMAN_CDP = "18585"
CROOK_TOWN = "18640"
CROWLEY_TOWN = "18750"
DACONO_CITY = "19080"
DAKOTA_RIDGE_CDP = "19150"
DE_BEQUE_TOWN = "19355"
DEER_TRAIL_TOWN = "19630"
DEL_NORTE_TOWN = "19795"
DELTA_CITY = "19850"
DENVER_CITY = "20000"
DERBY_CDP = "20275"
DILLON_TOWN = "20440"
DINOSAUR_TOWN = "20495"
DIVIDE_CDP = "20605"
DOLORES_TOWN = "20770"
DOTSERO_CDP = "21155"
DOVE_CREEK_TOWN = "21265"
DOVE_VALLEY_CDP = "21330"
DOWNIEVILLE_LAWSON_DUMONT_CDP = "21390"
DURANGO_CITY = "22035"
EADS_TOWN = "22145"
EAGLE_TOWN = "22200"
EAST_PLEASANT_VIEW_CDP = "22575"
EATON_TOWN = "22860"
ECHO_HILLS_CDP = "22882"
ECKLEY_TOWN = "23025"
EDGEWATER_CITY = "23135"
EDWARDS_CDP = "23300"
EL_JEBEL_CDP = "23795"
EL_MORO_CDP = "24290"
ELBERT_CDP = "23520"
ELDORA_CDP = "23575"
ELDORADO_SPRINGS_CDP = "23630"
ELIZABETH_TOWN = "23740"
ELLICOTT_CDP = "24235"
EMPIRE_TOWN = "24620"
ENGLEWOOD_CITY = "24785"
ERIE_TOWN = "24950"
ESTES_PARK_TOWN = "25115"
EVANS_CITY = "25280"
EVERGREEN_CDP = "25390"
FAIRMOUNT_CDP = "25550"
FAIRPLAY_TOWN = "25610"
FEDERAL_HEIGHTS_CITY = "26270"
FIRESTONE_TOWN = "26600"
FLAGLER_TOWN = "26765"
FLEMING_TOWN = "26875"
FLORENCE_CITY = "27040"
FLORISSANT_CDP = "27095"
FLOYD_HILL_CDP = "27175"
FORT_CARSON_CDP = "27370"
FORT_COLLINS_CITY = "27425"
FORT_GARLAND_CDP = "27535"
FORT_LUPTON_CITY = "27700"
FORT_MORGAN_CITY = "27810"
FOUNTAIN_CITY = "27865"
FOUR_SQUARE_MILE_CDP = "27950"
FOWLER_TOWN = "27975"
FOXFIELD_TOWN = "28105"
FRANKTOWN_CDP = "28250"
FRASER_TOWN = "28305"
FREDERICK_TOWN = "28360"
FRISCO_TOWN = "28690"
FRUITA_CITY = "28745"
FRUITVALE_CDP = "28800"
FULFORD_CDP = "28830"
GARDEN_CITY_TOWN = "29185"
GARDNER_CDP = "29240"
GARFIELD_CDP = "29295"
GENESEE_CDP = "29625"
GENOA_TOWN = "29680"
GEORGETOWN_TOWN = "29735"
GERRARD_CDP = "29845"
GILCREST_TOWN = "29955"
GLENDALE_CDP = "30350"
GLENDALE_CITY = "30340"
GLENEAGLE_CDP = "30420"
GLENWOOD_SPRINGS_CITY = "30780"
GOLD_HILL_CDP = "30945"
GOLDEN_CITY = "30835"
GOLDFIELD_CDP = "30890"
GRANADA_TOWN = "31550"
GRANBY_TOWN = "31605"
GRAND_JUNCTION_CITY = "31660"
GRAND_LAKE_TOWN = "31715"
GRAND_VIEW_ESTATES_CDP = "31935"
GREELEY_CITY = "32155"
GREEN_MOUNTAIN_FALLS_TOWN = "32650"
GREENWOOD_VILLAGE_CITY = "33035"
GROVER_TOWN = "33310"
GUFFEY_CDP = "33420"
GUNBARREL_CDP = "33502"
GUNNISON_CITY = "33640"
GYPSUM_TOWN = "33695"
HARTMAN_TOWN = "34520"
HARTSEL_CDP = "34630"
HASTY_CDP = "34685"
HASWELL_TOWN = "34740"
HAXTUN_TOWN = "34960"
HAYDEN_TOWN = "35070"
HEENEY_CDP = "35400"
HIDDEN_LAKE_CDP = "35860"
HIGHLANDS_RANCH_CDP = "36410"
HILLROSE_TOWN = "36610"
HOEHNE_CDP = "36940"
HOLLY_HILLS_CDP = "37220"
HOLLY_TOWN = "37215"
HOLYOKE_CITY = "37270"
HOOPER_TOWN = "37380"
HOT_SULPHUR_SPRINGS_TOWN = "37600"
HOTCHKISS_TOWN = "37545"
HOWARD_CDP = "37655"
HUDSON_TOWN = "37820"
HUGO_TOWN = "37875"
IDAHO_SPRINGS_CITY = "38370"
IDALIA_CDP = "38425"
IDLEDALE_CDP = "38480"
IGNACIO_TOWN = "38535"
ILIFF_TOWN = "38590"
INDIAN_HILLS_CDP = "38810"
INVERNESS_CDP = "38910"
JACKSON_LAKE_CDP = "39160"
JAMESTOWN_TOWN = "39195"
JANSEN_CDP = "39250"
JOES_CDP = "39745"
JOHNSON_VILLAGE_CDP = "39800"
JOHNSTOWN_TOWN = "39855"
JULESBURG_TOWN = "39965"
KEENESBURG_TOWN = "40185"
KEN_CARYL_CDP = "40377"
KERSEY_TOWN = "40515"
KEYSTONE_CDP = "40550"
KIM_TOWN = "40570"
KIOWA_TOWN = "40790"
KIRK_CDP = "40900"
KIT_CARSON_TOWN = "41010"
KITTREDGE_CDP = "41065"
KREMMLING_TOWN = "41560"
LA_JARA_TOWN = "42055"
LA_JUNTA_GARDENS_CDP = "42165"
LA_JUNTA_CITY = "42110"
LA_SALLE_TOWN = "43605"
LA_VETA_TOWN = "44100"
LAFAYETTE_CITY = "41835"
LAIRD_CDP = "42000"
LAKE_CITY_TOWN = "42330"
LAKESIDE_TOWN = "42495"
LAKEWOOD_CITY = "43000"
LAMAR_CITY = "43110"
LAPORTE_CDP = "43220"
LARKSPUR_TOWN = "43550"
LAS_ANIMAS_CITY = "43660"
LAZEAR_CDP = "44265"
LAZY_ACRES_CDP = "44270"
LEADVILLE_NORTH_CDP = "44375"
LEADVILLE_CITY = "44320"
LEWIS_CDP = "44595"
LEYNER_CDP = "44695"
LIMON_TOWN = "44980"
LINCOLN_PARK_CDP = "45145"
LITTLETON_CITY = "45255"
LOCHBUIE_TOWN = "45530"
LOG_LANE_VILLAGE_TOWN = "45695"
LOGHILL_VILLAGE_CDP = "45680"
LOMA_CDP = "45750"
LONE_TREE_CITY = "45955"
LONGMONT_CITY = "45970"
LOUISVILLE_CITY = "46355"
LOUVIERS_CDP = "46410"
LOVELAND_CITY = "46465"
LYNN_CDP = "47015"
LYONS_TOWN = "47070"
MANASSA_TOWN = "48060"
MANCOS_TOWN = "48115"
MANITOU_SPRINGS_CITY = "48445"
MANZANOLA_TOWN = "48500"
MARBLE_TOWN = "48555"
MARVEL_CDP = "48940"
MATHESON_CDP = "49215"
MAYBELL_CDP = "49325"
MAYSVILLE_CDP = "49490"
MCCLAVE_CDP = "47235"
MCCOY_CDP = "47345"
MEAD_TOWN = "49600"
MEEKER_TOWN = "49875"
MERIDIAN_CDP = "50012"
MERIDIAN_VILLAGE_CDP = "50026"
MERINO_TOWN = "50040"
MIDLAND_CDP = "50380"
MILLIKEN_TOWN = "50480"
MINTURN_TOWN = "50920"
MOFFAT_TOWN = "51250"
MONTE_VISTA_CITY = "51635"
MONTEZUMA_TOWN = "51690"
MONTROSE_CITY = "51745"
MONUMENT_TOWN = "51800"
MORGAN_HEIGHTS_CDP = "51975"
MORRISON_TOWN = "52075"
MOUNT_CRESTED_BUTTE_TOWN = "52570"
MOUNTAIN_MEADOWS_CDP = "52210"
MOUNTAIN_VIEW_TOWN = "52350"
MOUNTAIN_VILLAGE_TOWN = "52550"
MULFORD_CDP = "52820"
NATHROP_CDP = "53010"
NATURITA_TOWN = "53120"
NEDERLAND_TOWN = "53175"
NEW_CASTLE_TOWN = "53395"
NIWOT_CDP = "53780"
NO_NAME_CDP = "53875"
NORRIE_CDP = "53945"
NORTH_LA_JUNTA_CDP = "54495"
NORTH_WASHINGTON_CDP = "54750"
NORTHGLENN_CITY = "54330"
NORWOOD_TOWN = "54880"
NUCLA_TOWN = "54935"
NUNN_TOWN = "55045"
OAK_CREEK_TOWN = "55155"
OLATHE_TOWN = "55540"
OLNEY_SPRINGS_TOWN = "55705"
OPHIR_TOWN = "55870"
ORCHARD_CDP = "55925"
ORCHARD_CITY_TOWN = "55980"
ORCHARD_MESA_CDP = "56035"
ORDWAY_TOWN = "56145"
OTIS_TOWN = "56365"
OURAY_CITY = "56420"
OVID_TOWN = "56475"
PADRONI_CDP = "56695"
PAGOSA_SPRINGS_TOWN = "56860"
PALISADE_TOWN = "56970"
PALMER_LAKE_TOWN = "57025"
PAOLI_TOWN = "57245"
PAONIA_TOWN = "57300"
PARACHUTE_TOWN = "57400"
PARAGON_ESTATES_CDP = "57445"
PARK_CENTER_CDP = "57465"
PARKER_TOWN = "57630"
PARSHALL_CDP = "57850"
PEETZ_TOWN = "58235"
PENROSE_CDP = "58400"
PEORIA_CDP = "58510"
PERRY_PARK_CDP = "58592"
PEYTON_CDP = "58675"
PHIPPSBURG_CDP = "58785"
PIEDRA_CDP = "58960"
PIERCE_TOWN = "59005"
PINE_BROOK_HILL_CDP = "59240"
PINE_VALLEY_CDP = "59520"
PITKIN_TOWN = "59830"
PLACERVILLE_CDP = "59885"
PLATTEVILLE_TOWN = "60160"
PONCHA_SPRINGS_TOWN = "60600"
PONDEROSA_PARK_CDP = "60655"
PORTLAND_CDP = "60765"
PRITCHETT_TOWN = "61315"
PUEBLO_WEST_CDP = "62220"
PUEBLO_CITY = "62000"
RAMAH_TOWN = "62660"
RANGELY_TOWN = "62880"
RAYMER_NEW_RAYMER_TOWN = "63045"
RED_CLIFF_TOWN = "63265"
RED_FEATHER_LAKES_CDP = "63320"
REDLANDS_CDP = "63375"
REDSTONE_CDP = "63650"
REDVALE_CDP = "63705"
RICO_TOWN = "64090"
RIDGWAY_TOWN = "64200"
RIFLE_CITY = "64255"
ROCK_CREEK_PARK_CDP = "64870"
ROCKVALE_TOWN = "64970"
ROCKY_FORD_CITY = "65190"
ROLLINSVILLE_CDP = "65685"
ROMEO_TOWN = "65740"
ROXBOROUGH_PARK_CDP = "66197"
RYE_TOWN = "66895"
SADDLE_RIDGE_CDP = "66995"
SAGUACHE_TOWN = "67005"
SALIDA_CITY = "67280"
SALT_CREEK_CDP = "67445"
SAN_ACACIO_CDP = "67500"
SAN_LUIS_TOWN = "68105"
SANFORD_TOWN = "67830"
SAWPIT_TOWN = "68655"
SECURITY_WIDEFIELD_CDP = "68847"
SEDALIA_CDP = "68875"
SEDGWICK_TOWN = "68930"
SEGUNDO_CDP = "68985"
SEIBERT_TOWN = "69040"
SEVEN_HILLS_CDP = "69110"
SEVERANCE_TOWN = "69150"
SHAW_HEIGHTS_CDP = "69480"
SHERIDAN_LAKE_TOWN = "69700"
SHERIDAN_CITY = "69645"
SHERRELWOOD_CDP = "69810"
SIERRA_RIDGE_CDP = "70112"
SILT_TOWN = "70195"
SILVER_CLIFF_TOWN = "70250"
SILVER_PLUME_TOWN = "70360"
SILVERTHORNE_TOWN = "70525"
SILVERTON_TOWN = "70580"
SIMLA_TOWN = "70635"
SMELTERTOWN_CDP = "71625"
SNOWMASS_VILLAGE_TOWN = "71755"
SNYDER_CDP = "71790"
SOMERSET_CDP = "71845"
SOUTH_FORK_TOWN = "72395"
SOUTHERN_UTE_CDP = "72320"
SPRINGFIELD_TOWN = "73330"
ST_ANN_HIGHLANDS_CDP = "67040"
ST_MARYS_CDP = "67142"
STARKVILLE_TOWN = "73715"
STEAMBOAT_SPRINGS_CITY = "73825"
STEPPING_STONE_CDP = "73925"
STERLING_RANCH_CDP = "73943"
STERLING_CITY = "73935"
STONEGATE_CDP = "74080"
STONEWALL_GAP_CDP = "74275"
STRASBURG_CDP = "74375"
STRATMOOR_CDP = "74430"
STRATTON_TOWN = "74485"
SUGAR_CITY_TOWN = "74815"
SUGARLOAF_CDP = "74980"
SUNSHINE_CDP = "75585"
SUPERIOR_TOWN = "75640"
SWINK_TOWN = "75970"
TABERNASH_CDP = "76190"
TALL_TIMBER_CDP = "76325"
TELLURIDE_TOWN = "76795"
THE_PINERY_CDP = "77235"
THORNTON_CITY = "77290"
TIMNATH_TOWN = "77510"
TODD_CREEK_CDP = "77757"
TOWAOC_CDP = "78280"
TOWNER_CDP = "78335"
TRAIL_SIDE_CDP = "78345"
TRINIDAD_CITY = "78610"
TWIN_LAKES_CDP_ADAMS_COUNTY = "79100"
TWIN_LAKES_CDP_LAKE_COUNTY = "79105"
TWO_BUTTES_TOWN = "79270"
UPPER_BEAR_CREEK_CDP = "79785"
UPPER_WITTER_GULCH_CDP = "79800"
VAIL_TOWN = "80040"
VALDEZ_CDP = "80095"
VALMONT_CDP = "80370"
VERNON_CDP = "80755"
VICTOR_CITY = "80865"
VILAS_TOWN = "81030"
VINELAND_CDP = "81305"
VONA_TOWN = "81690"
WALDEN_TOWN = "82130"
WALSENBURG_CITY = "82350"
WALSH_TOWN = "82460"
WARD_TOWN = "82735"
WATKINS_CDP = "82900"
WELBY_CDP = "83120"
WELDONA_CDP = "83175"
WELLINGTON_TOWN = "83230"
WEST_PLEASANT_VIEW_CDP = "84042"
WESTCLIFFE_TOWN = "83450"
WESTCREEK_CDP = "83500"
WESTMINSTER_CITY = "83835"
WESTON_CDP = "84000"
WHEAT_RIDGE_CITY = "84440"
WIGGINS_TOWN = "84770"
WILEY_TOWN = "85045"
WILLIAMSBURG_TOWN = "85155"
WINDSOR_TOWN = "85485"
WINTER_PARK_TOWN = "85705"
WOLCOTT_CDP = "85760"
WOODLAND_PARK_CITY = "86090"
WOODMOOR_CDP = "86117"
WOODY_CREEK_CDP = "86200"
WRAY_CITY = "86310"
YAMPA_TOWN = "86475"
YUMA_CITY = "86750"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in North Carolina."""


ALAMANCE = "001"
ALEXANDER = "003"
ALLEGHANY = "005"
ANSON = "007"
ASHE = "009"
AVERY = "011"
BEAUFORT = "013"
BERTIE = "015"
BLADEN = "017"
BRUNSWICK = "019"
BUNCOMBE = "021"
BURKE = "023"
CABARRUS = "025"
CALDWELL = "027"
CAMDEN = "029"
CARTERET = "031"
CASWELL = "033"
CATAWBA = "035"
CHATHAM = "037"
CHEROKEE = "039"
CHOWAN = "041"
CLAY = "043"
CLEVELAND = "045"
COLUMBUS = "047"
CRAVEN = "049"
CUMBERLAND = "051"
CURRITUCK = "053"
DARE = "055"
DAVIDSON = "057"
DAVIE = "059"
DUPLIN = "061"
DURHAM = "063"
EDGECOMBE = "065"
FORSYTH = "067"
FRANKLIN = "069"
GASTON = "071"
GATES = "073"
GRAHAM = "075"
GRANVILLE = "077"
GREENE = "079"
GUILFORD = "081"
HALIFAX = "083"
HARNETT = "085"
HAYWOOD = "087"
HENDERSON = "089"
HERTFORD = "091"
HOKE = "093"
HYDE = "095"
IREDELL = "097"
JACKSON = "099"
JOHNSTON = "101"
JONES = "103"
LEE = "105"
LENOIR = "107"
LINCOLN = "109"
MACON = "113"
MADISON = "115"
MARTIN = "117"
MCDOWELL = "111"
MECKLENBURG = "119"
MITCHELL = "121"
MONTGOMERY = "123"
MOORE = "125"
NASH = "127"
NEW_HANOVER = "129"
NORTHAMPTON = "131"
ONSLOW = "133"
ORANGE = "135"
PAMLICO = "137"
PASQUOTANK = "139"
PENDER = "141"
PERQUIMANS = "143"
PERSON = "145"
PITT = "147"
POLK = "149"
RANDOLPH = "151"
RICHMOND = "153"
ROBESON = "155"
ROCKINGHAM = "157"
ROWAN = "159"
RUTHERFORD = "161"
SAMPSON = "163"
SCOTLAND = "165"
STANLY = "167"
STOKES = "169"
SURRY = "171"
SWAIN = "173"
TRANSYLVANIA = "175"
TYRRELL = "177"
UNION = "179"
VANCE = "181"
WAKE = "183"
WARREN = "185"
WASHINGTON = "187"
WATAUGA = "189"
WAYNE = "191"
WILKES = "193"
WILSON = "195"
YADKIN = "197"
YANCEY = "199"
